#
# spec file for package matomo
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# See also http://en.opensuse.org/openSUSE:Specfile_guidelines

%{!?_tmpfilesdir:%global _tmpfilesdir %{_prefix}/lib/tmpfiles.d}

Name:           matomo
Version:        4.6.2
Release:        bp154.1.36
Summary:        Web analytics platform
License:        GPL-3.0-or-later
Group:          Productivity/Networking/Web/Utilities
URL:            http://matomo.org/
Source0:        http://builds.matomo.org/%{name}-%{version}.tar.gz
Source2:        %{name}.conf
Source3:        %{name}.logrotate
Source4:        %{name}-README.SUSE
Source10:       %{name}-archive.cron
Source11:       %{name}-archive.service
Source12:       %{name}-archive.timer
Source13:       %{name}.my.cnf
Source14:       %{name}-tmpfile.conf
Source99:       %{name}.rpmlintrc
# PATCH-FIX-OPENSUSE: Don't show wrong message with wrong owner of %%{apache_serverroot}/%%{name} when disable enable_auto_update through package installation.
Patch1:         %{name}-package_update.patch
BuildArch:      noarch
%if 0%{?suse_version} >= 1500
Requires(pre):  user(wwwrun)
Requires(pre):  group(www)
%else
Requires(pre):  aaa_base
%endif
BuildRequires:  apache-rpm-macros
BuildRequires:  cron
BuildRequires:  fdupes
BuildRequires:  logrotate
BuildRequires:  mariadb
BuildRequires:  unzip
BuildRequires:  pkgconfig(systemd)
Requires:       nodejs
Requires:       python3
Requires:       logrotate
Requires:       php-ctype
Requires:       php-curl
Requires:       php-dom
Requires:       php-gd
Requires:       php-iconv
# for the upgrade process:
Requires(pre):  php-json
Requires:       php-json
Requires:       php-mbstring
Requires:       php-mysql
Requires:       php-pdo
#Requires:       php-sqlite
Requires:       php-tokenizer
Requires:       php-xmlreader
Requires:       php-xmlwriter
Requires:       php-zlib
Requires(pre):  php
%{?systemd_requires}
Recommends:     php-geoip
Recommends:     php-openssl
Recommends:     mariadb
Recommends:     cron
Conflicts:      piwik

%description
Matomo, formerly Piwik, is a web analytics platform that gives
insights into a website's visitors and marketing campaigns, so the
strategy and online experience of visitors may be optimized.

%package apache
Summary:        Apache configuration for %{name}
Group:          Productivity/Networking/Web/Utilities
BuildRequires:  apache2
Requires:       apache2
Requires:       mod_php_any >= 7.2.5
Recommends:     apache2-mod_geoip
Supplements:    packageand(apache2:%name)

%description apache
This subpackage contains the Apache configuration files

%prep
%setup -q -n %{name}
%patch1 -p1
install -m644 %{SOURCE4} README.SUSE
# remove unwanted files
find . -type f "(" -name .htaccess -o -name .travis.sh -o -name .gitkeep ")" -delete
#find . -name ".git*" -exec rm -Rf "{}" "+"
find . -type f "(" -name "*.c" -o -name "*.h" -o -name "*.js.orig" ")" -delete
# env-script-interpreter
find . -type f -exec sed -i -e 's|\/usr\/bin\/env php|\/usr\/bin\/php|g' {} +
find . -type f -name "*.sh" -exec sed -i -e 's|\/usr\/bin\/env bash|\/bin\/bash|g' {} +
sed -i 's|python$|python3|' misc/log-analytics/import_logs.py

#
# disable the auto updater, it can't work properly with the new, more secure permissions and is a bad idea on a RPM based setup anyways.
#
sed -i '/enable_auto_update/s/1$/0/' config/global.ini.php

#
# Fix integrity check triggered from fix of rpmlint errors.
# Drop moved files
for i in CHANGELOG.md CONTRIBUTING.md PRIVACY.md README.md SECURITY.md LEGALNOTICE LICENSE 'misc\/cron\/.htaccess' 'misc\/How to install Matomo.html' 'vendor\/tecnickcom\/tcpdf\/tools\/.htaccess' 'vendor\/twig\/twig\/ext\/twig\/php_twig.h' 'vendor\/twig\/twig\/ext\/twig\/twig.c' 'js\/piwik.js.orig' '.eslintignore' '.eslintrc.js' '.browserslistrc' 'vendor\/lox\/xhprof\/extension\/php_xhprof.h' 'vendor\/lox\/xhprof\/extension\/xhprof.c'
do
  sed -i "/\W\"${i}\"\W/d" config/manifest.inc.php
done
# Insert new hashes for chanded files
for file in console 'vendor/tecnickcom/tcpdf/tools/tcpdf_addfont.php' 'config/global.ini.php' 'core/CliMulti/Output.php' 'plugins/CoreUpdater/Commands/Update.php' 'vendor/matomo/matomo-php-tracker/run_tests.sh' 'vendor/wikimedia/less.php/bin/lessc' 'misc/log-analytics/import_logs.py' 'core/CliMulti.php'
do
  size=$(ls -l $file | awk '{ print $5 }')
  checksum=$(md5sum $file  | awk '{ print $1 }')
  file2=$(echo "$file" | sed 's/\//\\\//g')
  sed -i "/\W\"$file2\"\W/c \"$file\" => array(\"$size\", \"$checksum\")," config/manifest.inc.php
done

%build
# nothing to build

%install
# make directories
install -d -m0755 %{buildroot}/%{apache_serverroot}/%{name}
install -d -m0755 %{buildroot}/%{apache_serverroot}/%{name}/tmp
install -d -m0755 %{buildroot}/%{_sysconfdir}/%{name}
install -d -m0755 %{buildroot}/%{_defaultdocdir}/%{name}
# copy src from build to buildroot
mv *SUSE %{buildroot}/%{_defaultdocdir}/%{name}
mv LEGALNOTICE %{buildroot}/%{_defaultdocdir}/%{name}
mv LICENSE %{buildroot}/%{_defaultdocdir}/%{name}
mv "misc/How to install Matomo.html" %{buildroot}/%{_defaultdocdir}/%{name}
mv *md %{buildroot}/%{_defaultdocdir}/%{name}
cp -dR * %{buildroot}/%{apache_serverroot}/%{name}
# install matomo.conf to apache conf.d
mkdir -p %{buildroot}/%{apache_sysconfdir}/conf.d
sed -e 's|__matomo_web__|%{apache_serverroot}/%{name}|g' \
	-e 's|__matomo_conf__|%{_sysconfdir}/%{name}|g' \
	-e 's|__matomo_log__|/var/log/%{name}|g' \
	%{SOURCE2} > %{buildroot}/%{apache_sysconfdir}/conf.d/%{name}.conf
# install logrotate
install -D -m0644 %{SOURCE3} %{buildroot}/%{_sysconfdir}/logrotate.d/%{name}
sed -i -e 's|@APACHE_USER@|%{apache_user}|g' %{buildroot}/%{_sysconfdir}/logrotate.d/%{name}
sed -i -e 's|@APACHE_GROUP@|%{apache_group}|g' %{buildroot}/%{_sysconfdir}/logrotate.d/%{name}
# move config to etc/matomo and make symlink
mv %{buildroot}/%{apache_serverroot}/%{name}/config/* \
   %{buildroot}/%{_sysconfdir}/%{name}
rm -d %{buildroot}/%{apache_serverroot}/%{name}/config
ln -s %{_sysconfdir}/%{name} %{buildroot}/%{apache_serverroot}/%{name}/config
# install cronscript and systemd-timer
install -d -m 0755 %{buildroot}/%{_sysconfdir}/cron.d
install -d -m 0755 %{buildroot}/var/log/%{name}
install -D -m 0644 %{SOURCE10} %{buildroot}/%{_sysconfdir}/cron.d/%{name}-archive
install -D -m 0644 %{SOURCE11} %{buildroot}%{_unitdir}/%{name}-archive.service
install -D -m 0644 %{SOURCE12} %{buildroot}%{_unitdir}/%{name}-archive.timer
install -D -m 0644 %{SOURCE14} %{buildroot}%{_tmpfilesdir}/%{name}.conf
sed -i -e 's|@APACHE_USER@|%{apache_user}|g' %{buildroot}%{_sysconfdir}/cron.d/%{name}-archive
sed -i -e 's|@APACHE_SERVERROOT@|%{apache_serverroot}|g' %{buildroot}%{_sysconfdir}/cron.d/%{name}-archive
sed -i -e 's|@APACHE_USER@|%{apache_user}|g' %{buildroot}%{_unitdir}/%{name}-archive.service
sed -i -e 's|@APACHE_GROUP@|%{apache_group}|g' %{buildroot}%{_unitdir}/%{name}-archive.service
sed -i -e 's|@APACHE_SERVERROOT@|%{apache_serverroot}|g' %{buildroot}%{_unitdir}/%{name}-archive.service
# install changes for mariadb
install -D -m0644 %{SOURCE13} %{buildroot}/%{_sysconfdir}/my.cnf.d/%{name}.my.cnf

%fdupes %{buildroot}/%{_prefix}
%fdupes %{buildroot}/srv

%pre
%service_add_pre matomo-archive.timer matomo-archive.service

%post
# BSC#1154324
# # # chown -R %{apache_user}:%{apache_group} %{apache_serverroot}/%{name}
%service_add_post matomo-archive.timer matomo-archive.service apache2.service
%tmpfiles_create %{_tmpfilesdir}/%{name}.conf
if [ $1 -gt 1 ]; then
  # Update matomo if this is an upgrade $1 == 2
  echo "matomo: Update matomo:core..."
  su %{apache_user} -s /bin/sh -c "%{_bindir}/php %{apache_serverroot}/%{name}/console config:set 'Tracker.record_statistics="0"'" || :
  su %{apache_user} -s /bin/sh -c "%{_bindir}/php %{apache_serverroot}/%{name}/console config:set 'General.maintenance_mode="1"'" || :
  su %{apache_user} -s /bin/sh -c "%{_bindir}/php %{apache_serverroot}/%{name}/console core:update --yes" || :
  su %{apache_user} -s /bin/sh -c "%{_bindir}/php %{apache_serverroot}/%{name}/console config:set 'General.maintenance_mode="0"'" || :
  su %{apache_user} -s /bin/sh -c "%{_bindir}/php %{apache_serverroot}/%{name}/console config:set 'Tracker.record_statistics="1"'" || :
  :
fi

%preun
%service_del_preun matomo-archive.timer matomo-archive.service

%postun
%service_del_postun matomo-archive.timer matomo-archive.service apache2.service

%files
%defattr(-,root,root,-)
%dir %{_defaultdocdir}/%{name}
%{_defaultdocdir}/%{name}/*
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%config(noreplace) %{_sysconfdir}/cron.d/%{name}-archive
%config(noreplace) %{_sysconfdir}/my.cnf.d/%{name}.my.cnf
%{_unitdir}/%{name}-archive.service
%{_unitdir}/%{name}-archive.timer
%{_tmpfilesdir}/%{name}.conf
%dir %attr(0750,%{apache_user},%{apache_group}) %{_sysconfdir}/%{name}
%dir %attr(0750,%{apache_user},%{apache_group}) %{_sysconfdir}/%{name}/environment
%attr(0640,%{apache_user},%{apache_group}) %{_sysconfdir}/%{name}/*.php
%attr(0640,%{apache_user},%{apache_group}) %{_sysconfdir}/%{name}/environment/*.php
%ghost %attr(0750,%{apache_user},%{apache_group}) /run/%{name}_sessions
%defattr(644,root,root,755)
%dir %{apache_serverroot}/%{name}
%dir %attr(0750,%{apache_user},%{apache_group}) %{apache_serverroot}/%{name}/js
%dir %attr(0750,%{apache_user},%{apache_group}) %{apache_serverroot}/%{name}/misc
%dir %attr(0750,%{apache_user},%{apache_group}) %{apache_serverroot}/%{name}/plugins
%dir %attr(0750,%{apache_user},%{apache_group}) %{apache_serverroot}/%{name}/tmp
%dir %attr(0750,%{apache_user},%{apache_group}) /var/log/%{name}
%config(noreplace)  %attr(600,%{apache_user},%{apache_group}) %{_sysconfdir}/%{name}/*php
%{_sysconfdir}/%{name}/environment/*php
%attr(0644,%{apache_user},%{apache_group}) %{apache_serverroot}/%{name}/matomo.js
%attr(0644,%{apache_user},%{apache_group}) %{apache_serverroot}/%{name}/piwik.js
%attr(0644,%{apache_user},%{apache_group}) %{apache_serverroot}/%{name}/js/piwik.min.js
%attr(0770,%{apache_user},%{apache_group}) %{apache_serverroot}/%{name}/console
%attr(0770,%{apache_user},%{apache_group}) %{apache_serverroot}/%{name}/misc/cron/archive.sh
%attr(0770,%{apache_user},%{apache_group}) %{apache_serverroot}/%{name}/misc/log-analytics/import_logs.py
%attr(0770,%{apache_user},%{apache_group}) %{apache_serverroot}/%{name}/vendor/pear/archive_tar/sync-php4
%attr(0770,%{apache_user},%{apache_group}) %{apache_serverroot}/%{name}/vendor/szymach/c-pchart/coverage.sh
%attr(0770,%{apache_user},%{apache_group}) %{apache_serverroot}/%{name}/vendor/tecnickcom/tcpdf/tools/tcpdf_addfont.php
%attr(0770,%{apache_user},%{apache_group}) %{apache_serverroot}/%{name}/vendor/matomo/matomo-php-tracker/run_tests.sh
%attr(0770,%{apache_user},%{apache_group}) %{apache_serverroot}/%{name}/vendor/wikimedia/less.php/bin/lessc
%{apache_serverroot}/%{name}/*

%files apache
%config(noreplace) %{apache_sysconfdir}/conf.d/%{name}.conf

%changelog
* Fri Dec 10 2021 ecsos <ecsos@opensuse.org>
- Update to 4.6.2
  * matomo-org/matomo
  - #18444 Ensure UTF8mb4 conversion command always enables tracking again [by @sgiehl]
  - #18455 Ignore segment errors in update script [by @sgiehl]
  - #18473 Ensure update to 4.6.2 removes deleted files [by @sgiehl]
  - #18421 Remove unneeded plugin.json from CoreVue plugin [by @diosmosis]
* Wed Dec  1 2021 ecsos <ecsos@opensuse.org>
- Update to 4.6.1
  - In this release there is no code change but a change to the
    "Manifest File integrity list" to prevent a warning in the
    System check for some users.
* Tue Nov 30 2021 ecsos <ecsos@opensuse.org>
- Update to 4.6.0
  * matomo-org/matomo
  - #6784 Dashboard shows proportional evolution comparison for incomplete periods (rather than absolute values)
  - #3883 Row Evolution, Support Per-Goals and Ecommerce metrics: conversions, conversion rate, revenue and total revenue
  - #6032 Transitions reports: export full data as XML/JSON
  - #10291 Show difference in graphs for data of “unfinished periods” and “complete periods”
  - #14370 Remember “Rows to display” user preference for Evolution graphs
  - #17976 Scheduled tasks should not launch archiving
  - #8444 Ensure that the archive algorithm cannot be triggered multiple times for a same site/period/segment
  - #11627 JavaScript Tracker: Add possibility to set URL parameters to ignore
  - #18186 Improve in-app feedback mechanism to gain insight from users about pain points
  - #18036 Optimise ecommerce life time metric query
  - #18079 Make error messages not leak potentially sensitive information when tracker db connection fails
  - #18244 Ensure DNS records are only requested for IP allowlist when needed
  - #18232 Remove “refer us” feature
  - #18250 Remove review popup
  - #18251 Collect feedback about what features people are using?
  - #3513 Column names could stick to the top of screen when scrolling down report tables
  - #16607 More verbose error message when login nonce check fails
  - #18164 Install routine: Fix text contrast for accessibility
  - #17589 Add config option to disable http requests in System Checks to prevent server crashes with mod_security
  - #17856 [database_tests] section no longer generated when executing php tests
  - #18133 JSONp API request (with callback) strips first and last character from result
  - #18178 Fix segment creation fails when enable_create_realtime_segments = 0
  - #18313 Newsletter Signup in personal settings, mention Matomo privacy policy applies
  - #17815 Improve UI of report info icon to show report generation time and help message
  - #18058 Add system check for 32 bit PHP / OS
  - #18070 New console command “marketplace:add-license-key” which adds a marketplace license key
  - #18107 Add more granular access control for segment creation
  - #18162 Close Tooltip when redirecting to another page
  - #18152 Improve performance of Process::isSupported by caching it
  - #18157 Make cli archiving faster if only one concurrent request per website is configured
  - #18172 Fix initial export option values so checkbox shows correct value
  - #18211 Updates davaxi/sparkline to 2.0 to PHP8.1 compatible version
  - #18215 Fix CSP issue when viewing marketplace plugin details
  - #15429 Mention guides for Wix, WordPress, SquareSpace, Sharepoint in the “No data” email and in the “Tracking code” pag
  - #17602 Fix 2-lines label overflows the input
  - #17786 Install routine: language changer line height improvements
  - #11175 Improve help text on ‘Users’ report when no data
  - #17010 When “average generation time” is zero, hide the sparkline and “Avg generation time” graphs metric from picker
  - #17890 Remove “add new segment” selector in segment editor
  - #17996 Manage Users: When user is admin, mention other users might exist
  - #17973 Remove Provider and CustomVariables plugin from our core release
  - #18011 Update list of no longer supported browsers (IE11)
  - #17923 Make SecurityPolicy methods a public API and fully enable the CSP
  - #16153 Tracking request may trigger a warning when providing an invalid regex
  - #14695 Special character apostrophe is not getting printed properly in visits log (campaign url)
  - #16067 Fix dashboard showing incorrect percentage on increases bigger than 1000%%
  - #17939 Include lox/xhprof in the Matomo build release so Profiling works
  - #18019 Make the opt out work when a PHP 32 bit is used
  - #18130 Fixed in place sorting order bug for PHP8+
  - #18231 Fix annotations for “Behaviour > Performance” StackedBarEvolution charts
  - #18267 Decode goal top dimension values
  - #10550 Add field lastSeen in the API for the UsersManager
  - #17916 Introduce new config setting to set a contact email address
  - #17940 [Vue] Introduce Vue + Workflow commands
  - #18071 Provide console command for adding a marketplace license key (#18070)
  - #18074 Update container factory to allow for sorting plugins
  - #18110 Use detachEvent when removeEventListener isn’t available
  - #18123 Don’t browser archive when segment is set to be pre-processed
  - #18137 Make the Twig cache template path more configurable with a DI entry
  - #18149 Fix error cannot read property “replace” of undefined in quick search
  - #18156 Small optimisations to Archiving performance
  - #18166 [Vue] Migrate content-block, enriched-headline, rate-feature + related
  - #18187 Fix possible problem with CSP in overlay feature
  - #18193 [Vue] migrate comparisons service + component
  - #18204 Always remove hash part from URL when detecting the script name
  - #18213 [Vue] migrate date-picker and other period-selector related components
  - #18214 [Vue] migrate dropdown and related directives
  - #18225 [Vue] migrate notifications directive & service + UI.Notifications
  - #18235 Changes to keep sorting order consistent across all PHP versions for Live.getLastVisitsDetails API
  - #18241 Take archive TTL time into consideration for today when browser archiving is enabled
  - #18255 Fix archiving too many segments that aren’t needed and showing 0 conversions for new visits/returning visitors
  - #18263 Support downloading system tests from plugins
  - #18278 Remove cache clearing from forget invalidations loop.
  - #18300 Corrected paths mentioning “piwik/” to “/path/to/matomo/”.
  - #18309 Couple of fixes in QuickForm2 for PHP8.1 compatibility
  * matomo-org/tag-manager
  - #217 Enable Debugging mode without URL parameter
  - #375 Right clicks trigger twice for “All Links Click” and “All Elements Click” in Firefox
  - #378 Fix deprecation warning on PHP 8.1
  * matomo-org/device-detector
  - #5773 Add detection for Google Podcasts
  - #6793 Improvements for the OS parser a second level of regular expressions has been added
  - #6870 Detect devices for existing brands: Xiaomi, Samsung, Realme, Tecno Mobile, Mobicel, Vivo, Lenovo, ZTE,
    OPPO, Oukitel, CUBOT, UMIDIGI, OnePlus, Ulefone, Doogee, TCL, Vivo, Vertex, Infinix, Krüger&Matz, Wiko, DEXP, BQ
  - #6872 Detect new brand Nubia
  - #6873 Detect new brands: Bluebird, Mara and Detect devices for existing brands: Krüger&Matz, iHunt, Sony, Teclast,
    Tanix, Logicom, Nubia, Xiaomi, QMobile, DIXON, Zuum, Vodacom, Mobicel, Oukitel, Motorola, Stylo, Tecno Mobile,
    Chuwi, OnePlus, Vivo, iTel, Doogee, Cat, Homtom, CUBOT, MLS, Blu, Casper, Unonu
  - #6874 Detect new brands: BMAX, Geotex and Detect devices for existing brands: Telefunken, Asus, Huawei, Lenovo,
    Tecno Mobile, Nomi, Coolpad, Blu, Navitel, Winnovo, Digiland, DEXP, Sony, Inoi, OPPO, Samsung, Xiaomi, LG, Vivo,
    UMIDIGI, Mobicel, Teclast, Zuum
  - #6877 Detect new brand: Rakuten and Detect devices for existing brands: Beelink, Sony, Blackview, Samsung,
    NUU Mobile, Oukitel, Coolpad, LG, DEXP, Acer, ZTE, TCL, Mobicel, Contixo, BQ, ONYX BOOX, Mecer, Digma, Lenovo,
    RCA Tablets, Intex, Huawei, Santin, Vivo, NOA, iTel, Sharp, Prestigio, HTC, OnePlus, Wiko, Fly, Meizu, Lava, Gionee
  - #6878 detect the device type for other browsers (Huawei, Quark, MQQBrowser)
  - #6879 Detect devices for existing brands: Vivo, Huawei, ZTE, Smartisan, Samsung, OPPO, HTC, Xiaolajiao, POCO, Xiaomi, Blu
  - #6880 Adds detection for Apple iPhone 13 models
  - #6881 Detect device type for chrome forks
  - #6883 Detect devices for existing brands: Vivo, HTC, Hisense, Gionee, Huawei, Samsung, Realme, Blu, NOA
  - #6885 Detect oss: Java ME, REX
  - #6886 Detect new brand: DING DING and Detect devices for existing brands: Zopo, F2 Mobile, iBall, Krüger&Matz,
    Hotwav, Orange, Tecno Mobile, Runbo, Vonino, M4tel, Kempler & Strauss, Rokit, Stylo, DEXP, Prestigio, Mobicel, Santin
  - #6888 Detect devices for existing brands: X-TIGI, Prestigio, Micromax, LG, DEXP, Oukitel, Hurricane, Alcatel,
    M4tel, Blackview, S-TELL, Coolpad, HTC, Teclast, Mecer, Huawei, Reeder, Orange, Mobicel, Realme, NUU Mobile,
    Xiaomi, Huawei, Hisense, Zuum, Krüger&Matz, Motorola
  - #6889 Adds detection for GitHub Desktop and Logi Options+ apps
  - #6890 Adds detection for Bonsai, Peeps dBrowser, Flash, Harman, Lagatos, LT, PSI, Spectre and Sushi Browsers
  - #6891 Adds detection for Roku OS
  - #6892 Adds detection for OpenWrt OS and uclient-fetch library
  - #6894 Adds detection for multiples apps and improves iOS, Windows, iPhone, iPod detection
  - #6895 Detect devices for existing brands: Nubia, F150, Vivo, Huawei, Realme, Google, Oukitel, TCL, Packard Bell,
    Xiaomi, Cube, Lenovo, OnePlus, iHunt, Proline, Reeder, Stylo, Hurricane, OPPO, Mobicel, Ugoos, Beeline, 4Good,
    Teclast, K-Touch, Prestigio, Tecno Mobile, AllDocube, Ravoz, T-Mobile, DIXON, Motorola, Asus
  - #6897 Detect new brands: Trident, SUNWIND, OKSI, Taiga System and Detect devices for existing brands: TechPad,
    Santin, Realme, Meizu, Alcatel, Xiaomi, ONN, UMIDIGI, DEXP, Premio, Oukitel, Coolpad, Sky, Huawei, Stylo, Mobicel,
    Casper, Infinix, TCL, Qumo
  - #6899 Adds detection for Apple Watch Series 7
  - #6900 Improves detection for Apple devices
  - #6901 Improves detection for Hisense, Samsung and TCL devices
  - #6902 Improves Android, iPadOS, iOS, macOS version detection
  - #6903 Improves detection for iOS, iPadOS, macOS, Android, Windows, Apple, Motorola, Samsung and Sony brands,
    and adds detection for Telco brand and various apps
  - #6904 Adds detection for Cellution, Juniper Systems, Kazuna, Oculus, STRONG, Topelotek brands and improves detection for
    Alcatel, Amazon, ANS, Kocaso, LG, Motorola, Sony, UMIDIGI brands
  - #6905 Adds detection for various apps
  - #6906 Detect new brands: Glofiish, Polar, MyGica and Detect devices for existing brands: Cavion, Stylo, Mobicel,
    Hurricane, Proline, bq, Hisense, Archos, NOA, GOCLEVER, Blackview, Blu
  - #6907 Adds detection for KRIP brand, improves detection for Alcatel, Blu, BMobile, Epik One, Gateway, Huawei, Hyundai,
    IKU Mobile, MobiWire, MicroMax, Positivo, Safaricom, TCL, UMIDIGI, Vivo brands and improves detection for Opera GX,
    Windows, x86, x64 platforms
  * matomo-org/matomo-php-tracker
  - #97 Fix for double newline issue when a redirect is used
  - #98 Couple of fixes for PHP 8.1
* Thu Oct  7 2021 ecsos <ecsos@opensuse.org>
- Update to 4.5.0
  * matomo-org/matomo
  - #17870 Improve I/O performance by not writing placeholder files when they already exist
  - #17732 Users can get logged out when many notifications are pending
  - #17853 Clicking through the following pages in the transition overlay for page titles does not work
  - #17872 If the period is not enabled in config “The period is not supported” message is shown in cron archiving
  - #17926 Console error “There was an error setting cookie `mtm_cookie_consent`.
    Please check domain and path.” when calling ‘rememberCookieConsentGiven’
  - #17965 In Acquisition > Overview report, the Row selector is missing
  - #17966 Warning DataCollection.php(381): Notice – Undefined index: 2021-04-26,2021-05-02
  - #17091 Failing SMTP connection might result in information disclosure in password recovery
  - #17773 Matomo should be setting content security policy to prevent some XSS
  - #18030 Remove fallback to mt_rand and always use random_int for secure randomness
  - #2672 New INI config setting for Custom image to replace default 1×1 GIF image
  - #16576 New console command config:delete to delete a key
  - #16859 Add JS tracker methods setPagePerformanceTiming and getCustomPagePerformanceTiming to set
    specific values for performance metrics
  - #17738 Don’t log an error when not supported browser is used
  - #14719 Run OPTIMIZE TABLE on each table in a separate SQL query to work better with replication
  - #15322 Removed misleading help text from segment dimensions tooltip
  - #15892 ‘Acquistion/Overview/Evolution over the period’ graph fails when adding more channels
  - #16529 Old data in log tables without idvisit column are not purged (affects plugins)
  - #15036 Hide “AND segmented reports are pre-processed (faster, requires cron)” from
    the UI when enable_create_realtime_segments = 0
  - #15135 Link to a helpful FAQ in the error message “Oops, there was a problem during the request.”
  - #15335 When configuring an e-mail report, the selected segment is not saved
  - #16604 Update RegEx extractions help text to show slashes don’t need escaping
  - #17577 Split private directories system check into “Required” and “Recommended”
  - #16834 Use row_format=dynamic by default when creating a table
  - #18012 Add warning about dropping support for IE11 in Matomo user interface
  - #18039 Remove not used DB adapters
  - #16459 Heartbeat timer ping request is not always sent
    (focusing away from the tab should trigger the ping request)
  - #17640 Page Overlay ignores token_auth in URL when opened from a Widget
  - #17752 Automatically delete plugin specific/report specific invalidations that do not need to run
  - #17787 Javascript console error when clicking Install routine: Download System Check button
  - #17816 Limiting ecommerce product reports to 10,000 to avoid memory issues with new INI config setting to customise
  - #17871 Added info message that INI setting archiving_query_max_execution_time may not work for MySQLI
  - #17883 Possible warning notices during log archive
  - #17925 The selected [Allow multiple conversions per visit] option is not displayed when editing a goal
  - #18046 For login allow list add support for IPv6
  - #17817 When aggregating reports, inflate one expanded datatable at a time
  - #17818 get rid of stashed datatables before going into safe mode to free up memory
  - #17846 Remove checking for /proc existence
  - #17849 Scheduled tasks: Always read timetable from the database and not from memory
  - #17855 Use Monolog:SyslogHandler syslog default facility
  - #17867 Do not log a failed login if a valid app token_auth is sent
  - #17869 Fix a couple a possible warnings in PHP 8.1
  - #17877 Only set requests in tracking request set when correct value is given
  - #17891 Ignore overwrite subtable warning for summary rows for old data to avoid re-archiving for a single row
  - #17905 Update cache component
  - #17910 Expose methods to disable content security policy or loosen it for embedded iframes
  - #17937 Load sparkline images only once they are near view port
  - #17943 When processing a dependent archive for a range, then only process the requested plugin, not all plugins
  - #17949 try and reconnect database after running each scheduled task (at most once per two hours) during core:archive
  - #17992 Update doctrine cache to the right version
  - #18023 Allow social & search definitions to be sourced locally
  - #18024 Check config file was written correctly
  - #18033 Allow scheduled report emails to be differentiated from other emails
  - #18042 removed files related to unsupported databases
  - #18074 Update container factory to allow for sorting plugins
  * matomo-org/tag-manager
  - #217 Enable Debugging mode without URL parameter
  - #208 Added option to configure cookie domain in configuration
  - #328 Observe DOM element changes even when a user doesn’t scroll on the page
  - #339 Visibility trigger add feature to observe DOM changes etc.
  - #49 Make Matomo tag parameters descriptions translatable
  - #225 Explain what the Tag Manager “Enable DNT” setting in the Matomo Configuration variable does
  - #268 New “Click Button” variable and “All Elements Click” and “All Links Click” will trigger on middle and right click also
  - #349 The `WindowUnload` event should be triggered only once for Microsoft Internet Explorer in Edge mode
  - #362 Element visibility trigger may trigger too often
  - #344 Visibility trigger add feature to observe DOM changes
  * matomo-org/device-detector
  - #6477 Adds detection for Secure Browser
  - #6546 Adds detection for tvOS and removes Apple TV
  - #6812 Added detection for existing brands: AT&T, Tecno Mobile, Vivo, Blu, Philips, Phonemax,
    Motorola, Ulefone, ZTE, DEXP, JVC, UMIDIGI, F150, Neffos, Nomi, Nomu, NOA, Inoi, Doogee,
    Senseit, Pixus, Mintt, Mobicel
  - #6813 Added detection for existing brands: ZTE, HTC, Lenovo, Doogee, Prestigio, GOCLEVER,
    iLife, Explay, Blu, Vivo, Overmax, Vertex, Blackview
  - #6815 Added detection for bots: LinkPreview, JungleKeyThumbnail
  - #6817 Adds detection for various bots
  - #6818 Added detection for mobile app: NTV Mobil
  - #6819 Detect devices for existing brands: Infinix, Oukitel, Inoi, Wileyfox, Teclast, Iris,
    Umax, Sencor, Meizu, Huawei, Blu, MyPhone, Hisense, ZTE, Vivo
  - #6822 Detect devices for existing brands: Doro, Xiaomi, Turbo-X, Majestic, Energizer,
    Ulefone, Prestigio, Nomi, NGM, Lenovo, Blu, HTC, ZTE, Motorola, Digma
  - #6824 Detect devices for existing brands: Santin, Ulefone, DEXP, TrekStor, Teclast, Asus,
    Neffos, Nobby, Xiaomi, ZTE, OPPO, Wiko, Lenovo, LT Mobile, MLS, Vertex, MyPhone, Lava,
    HTC, Palm, Jinga, Archos, Bravis, Nomi, Elephone
  - #6825 Detect bot Turnitin
  - #6827 Detect devices for existing brands: A1, Huawei, Crosscall, Samsung, Tecno Mobile,
    Teclast, Realme, Reeder, Leagoo, OPPO, Sony, Asus, Sharp, Fujitsu, Xiaomi, Motorola
  - #6828 Detect app TikTok for Android
  - #6829 Adds bot detection Google StoreBot
  - #6830 Detect new brands Adronix, ProVision and Detect devices for existing brands:
    AllDocube, Asus, Fujitsu, Huawei, Xiaomi, Lenovo, Motorola, Openbox, Karbonn,
    Lava, Vivo, Meizu, Hoozo, Realme, Krüger&Matz
  - #6834 Adds bot detection Dotcom Monitor
  - #6835 Detect apps: AliExpress, QuickCast, Blue Proxy, COAF SMART Citizen
  - #6837 Detect devices for existing brands: Alcatel, MTC, HTC, Nokia, Vivo, Samsung,
    OnePlus, Nomi, ONN, Tecno Mobile, Realme, Blackview, LG, Lenovo, Motorola, Digma,
    Fairphone, Homtom
  - #6839 Detect new brand Sirin labs and Detect devices for existing brands:
    Google, Vivo, POCO, OPPO, Sony, Sharp, Oukitel, Lenco, iVA, Doogee, MyPhone,
    M-Horse, Dialog, Digma, Energizer, Santin, MDC Store, 4Good, Matrix, Allwinner,
    Prestigio
  - #6840 Detect new brands: Anker, Perfeo, CGV and Detect devices for existing brands:
    Hoffmann, Huawei, Lenovo, Prestigio, Coolpad, Digiland, Reeder, Xiaomi, Realme,
    Oukitel, Oale, Tecno Mobile, Medion, Teclast, Kyocera, Gionee, MTC, Alcatel,
    DEXP, Irbis
  - #6842 Adds browser detection for Stampy Browser
  - #6843 Add Amazonbot and simplify some bot regexes
  - #6845 Detect bots: ThinkChaos, DataForSeoBot
  - #6846 Detect new brands: Telia, Canal Digital and Detect device OPPO A16
  - #6847 Detect new brand ZIFRO and Detect devices for existing brands:
    Blu, Prestigio, Bluboo, Leagoo, Motorola, Sigma, Google, Tecno Mobile, Archos,
    Xiaomi, Ginzzu, Qumo, UMIDIGI, DEXP, EE, CUBOT, Amoi, Xgody, Sony, IconBIT,
    MegaFon, OPPO
  - #6850 OS family added to operating system parse result
  - #6851 Detect brand Google model: Chromecast (2020)
  - #6852 Detect new brands: SmartBook, Covia, Qubo, Bundy, Sprint, Kiowa and
    Detect devices for existing brands: F2 Mobile, QMobile, KINGZONE, Mobicel,
    Vodafone, HTC, Bmobile, Gome, Cherry Mobile, Oukitel, Alcatel, Sunny,
    Primux, Sky, Vestel, iView, Realme, Ainol, IconBIT
  - #6854 Detect brand Huawei model: Nexus 6P
  - #6856 Detect new brands: Smart, Stylo, Galaxy Innovations, Benzo, Exmart and
    Detect devices for existing brands: GOCLEVER, Hurricane, Gresso, Mobicel,
    Riviera, Haier, Alcatel, Kanji, Karbonn, NextBook, Leader Phone, Leotec,
    TrekStor, Highscreen, Starmobile, Blu, Lava, Gome, Hyundai, Carrefour,
    F2 Mobile, Xiaomi, Sony, Sico, Amazon, Asus
  - #6857 Rename brand 2F Mobile to F2 Mobile
  - #6859 Detect app TikTok for iOS
  - #6861 Detect OS HarmonyOS
  - #6863 Detect browser GoBrowser for Symbian
  - #6865 Improved browser engine detection for Tenta browser
  - #6866 Detect new brands: Vexia, AIRON, Mymaga, HiMax, Packard Bell, Qnet Mobile and
    Detect devices for existing brands: Hyundai, Odys, Inco, Amazon, NEC, Sony, iMars,
    Qubo, Mito, DNS, Lark, Timovi, Masstel, Telefunken, Luna, MyPhone, Leader Phone,
    Elephone
  - #6868 Detect New Model: Mi Mix 4
  - #6870 Detect devices for existing brands: Xiaomi, Samsung, Realme, Tecno Mobile,
    Mobicel, Vivo, Lenovo, ZTE, OPPO, Oukitel, CUBOT, UMIDIGI, OnePlus, Ulefone,
    Doogee, TCL, Vivo, Vertex, Infinix, Krüger&Matz, Wiko, DEXP, BQ
  - #6872 Detect new brand Nubia
  - #6873 Detect new brands: Bluebird, Mara and Detect devices for existing brands:
    Krüger&Matz, iHunt, Sony, Teclast, Tanix, Logicom, Nubia, Xiaomi, QMobile, DIXON,
    Zuum, Vodacom, Mobicel, Oukitel, Motorola, Stylo, Tecno Mobile, Chuwi, OnePlus,
    Vivo, iTel, Doogee, Cat, Homtom, CUBOT, MLS, Blu, Casper, Unonu
  - #6874 Detect new brands: BMAX, Geotex and Detect devices for existing brands:
    Telefunken, Asus, Huawei, Lenovo, Tecno Mobile, Nomi, Coolpad, Blu, Navitel,
    Winnovo, Digiland, DEXP, Sony, Inoi, OPPO, Samsung, Xiaomi, LG, Vivo, UMIDIGI,
    Mobicel, Teclast, Zuum
  * matomo-org/referrer-spam-list
  - #1284 Add rczhan.com
  - #1285 Add hsoutdoor.com
  - #1286 Add czcedu.com
  - #1287 Add amatocanizalez.net
  - #1288 Add gcmx.net
* Mon Aug  2 2021 ecsos <ecsos@opensuse.org>
- Update to 4.4.1
  * matomo-org/matomo
  - #17829 Testcookie causes warning in browser console
  - #17835 Fix sorting of Geolocation providers
  - #17838 More warnings about missing shell_exec() since Matomo 4.4.0
  - #17831 make sure summary rows are serialized with their in-db
    subtable ID and not in memory one
  - #17832 Add command to generate a system check
  - #17842 Revert “more private Referrer-Policy: use
    strict-origin-when-cross-origin ”
  * matomo-org/device-detector
  - #6811 Detect devices for existing brands: Lenovo, Xiaomi,
    Samsung, Asus, ZTE, Vivo, Hyundai, Motorola, NYX Mobile,
    OPPO, LG, Sharp, Realme
- Fix integrity check for misc/log-analytics/import_logs.py.
* Wed Jul 28 2021 ecsos <ecsos@opensuse.org>
- Update to 4.4.0
  * Breaking Changes
  - The logme method for automatic logins is now disabled by
    default for new installations. For existing installations it
    will be enabled automatically on update. If you do not need
    it please consider disabling it again for security reasons
    by setting login_allow_logme = 0 in General section of
    config.ini.php.
  - The redirect using the url param for the automatic
    login action logme, will no longer do redirects to untrusted
    hosts. If you need to do redirects to other URLs on purpose,
    please add the according hosts as trusted_hosts entry in
    config.ini.php
  * New config.ini.php settings
  - When determining the client IP address from proxy headers
    like X-Forwarded-For, Matomo will by default look at the first
    IP in the list. If you need to read the last IP instead,
    the new INI config option [General] proxy_ip_read_last_in_list
    be set to 1. Using the last IP can be more secure when you are
    using proxy headers in combination with a load balancer.
  - Matomo logs can now be written into "errorlog" (logs using
    the error_log() php function) and "syslog" (logs to the
    syslog service) (to complement existing log writers:
    "screen", "file", "database"). Learn more.
  * New commands
  - Added new command core:version which returns the Matomo
    version number.
* Tue Jul 27 2021 Steve Kowalik <steven.kowalik@suse.com>
- Change shebang of misc/log-analytics/import_logs.py to be python3.
* Wed May 26 2021 ecsos <ecsos@opensuse.org>
- Update to 4.3.1
  * New commands
  - Added new command core:create-security-files which creates
    some web server security files if they haven't existed
    previously (useful when using for example Apache or IIS web
    server).
* Mon May 17 2021 ecsos <ecsos@opensuse.org>
- Update to 4.3.0
  * Breaking Changes
  - Before every JS error was tracked, from this version the same
    JS error will be only tracked once per page view. If the very
    same error is happening multiple times, then it will be
    tracked only once within the same page view. If another page
    view is tracked or when the page reloads, then the error will
    be tracked again.
  - It's no longer possible to store any class instances directly
    in the session object. Please use arrays or plain data instead.
  * Upcoming Breaking Changes
  - In Matomo 4.3.0 we have added a 'passwordConfirmation'
    parameter to the CorePluginsAdmin.setSystemSettings API
    method. It is currently optional, but will become mandatory
    in version 4.4.0. Plugin developers and users of the API
    should make sure to update their plugins and apps before this
    happens.
  * New config.ini.php settings
  - The password_hash_algorithm, password_hash_argon2_threads,
    password_hash_argon2_memory_cost and
    password_hash_argon2_time_cost INI config options have been
    added to allow using specific password_hash algorithms and
    options if desired.
  - The enable_php_profiler INI config option was added. This
    must now be set to 1 before profiling is allowed in Matomo.
  For a full changelog, look at:
  https://github.com/matomo-org/matomo/releases/tag/4.2.1
  https://matomo.org/changelog/matomo-4-3-0/
- Rebase matomo-package_update.patch.
* Mon Mar  1 2021 ecsos <ecsos@opensuse.org>
- Update to 4.2.1
  To many changes, so look at:
  https://github.com/matomo-org/matomo/releases/tag/4.2.1
* Mon Feb 22 2021 ecsos <ecsos@opensuse.org>
- Update to 4.2.0
  To many changes, so look at:
  https://github.com/matomo-org/matomo/releases/tag/4.2.0
* Fri Jan 15 2021 ecsos <ecsos@opensuse.org>
- Update to 4.1.1
  To many changes, so look at:
  https://github.com/matomo-org/matomo/releases/tag/4.1.1
* Tue Dec 22 2020 ecsos <ecsos@opensuse.org>
- Update to 4.1.0
  - No changelog from upstream at this time.
* Mon Dec 14 2020 ecsos <ecsos@opensuse.org>
- Put apache configuration files in separate subpackages.
- Update cron, service, lograte files with apache macros.
* Wed Dec  9 2020 ecsos <ecsos@opensuse.org>
- Update to 4.0.5
  - Avoid inserting duplicates in invalidation table to reduce IO.
  - Limit to given sites to not select too much.
  - fix build
  - tweaks to duplicate checking query
  - more pr feedback
  - fix cron archive test
* Fri Dec  4 2020 ecsos <ecsos@opensuse.org>
- Update to 4.0.4
  - No changelog from upstream.
* Wed Dec  2 2020 ecsos <ecsos@opensuse.org>
- Use apache-rpm-macros.
* Sat Nov 28 2020 ecsos <ecsos@opensuse.org>
- Update to 4.0.2
  No changelog from upstream but you can see changes since 4.0.1
  here: https://github.com/matomo-org/matomo/compare/4.0.1...4.0.2
* Fri Nov 27 2020 ecsos <ecsos@opensuse.org>
- Update to 4.0.1
  * matomo-org/matomo
  - #16778 SEO Plugin broken
  - #16788 CLI Archive might not stop
  - #16786 No custom dimensions in Matomo 4.0.0
  - #16798 Error upgrading db while upgrading to 4.0.0-b1
    (session update fails)
  - #16804 Matomo 4.0.0 warns about “ExampleTheme requires
    Piwik <4.0.0-b1”
  * matomo-org/device-detector
  - #6443 Detect browsers: Slimjet, 7Star, MxNitro
  - #6444 Detect new brands: Starlight, GEOFOX, Verico, Tinmo,
    Matrix and Detect devices for existing brands: Asus, Sharp,
    Coolpad, Sony, OPPO, Lenovo, Philips, Vivo, Xiaomi,
    Manta Multimedia, NEC, Vernee, Karbonn, Krüger&Matz, RugGear,
    DEXP, Digma, MiXzo, Atom, Yu, Acer, Irbis, teXet, Telefunken,
    Onda, IconBIT, Polaroid, Doogee, Allview, BB Mobile,
    Touchmate, ArmPhone, Memup, Kazam, ZTE, Odys, Jinga, Ginzzu,
    iLife, Mobicel, Blu, Blaupunkt
    [#6448] Detect Crazy Browser
* Tue Nov 24 2020 ecsos <ecsos@opensuse.org>
- Update to 4.0.0
  Too many changes to list here. See instead:
  https://github.com/matomo-org/matomo/releases/tag/4.0.0
- Fix boo#1162178:
  Add matomo-package_update.patch to not show warning message when
  auto_update_enable es disable through package installation.
* Mon Oct  5 2020 ecsos <ecsos@opensuse.org>
- Update to 3.14.1
  * matomo-org/matomo
  - #16223 piwik-php-tracker missed after update
  - #16382 Urgent update to Danish translation
  - #16210 Allow plugins to configure custom user preferences
  - #16291 Official PHP Reporting Client, or at least link those that already exist
  - #16295 Number formatting may be wrong when eg German language is used
  - #16322 Fix plugins might not be updated when updating core
  * matomo-org/matomo-php-tracker
  - #61 Tracker does not set samesite cookie
  - #73 Make it possible to configure cookie options for Secure, HTTPOnly and SameSite
  * matomo-org/matomo-log-analytics
  - #273 When input is stdin (‘-‘), import_logs.py doesn’t work
  - #274 always disable queued tracking when sending requests from log import
  * matomo-org/tag-manager
  - #252 Improve detection of preview release if it wasn’t detected previously somehow
  * matomo-org/matomo-package
  - #112 Ship Matomo with Provider and Custom Variables plugin
  * matomo-org/device-detecto
  - #5389 Iceweasel should be tracked as Firefox
  - #5713 WebOS regex is incorrect.
  - #6075 Fixed version truncation so one client doesn’t affect the others
  - #6292 Adds detection for multiple notebooks
  - #6321 add sistrix crawler
  - #6324 Detect new brand: 360, Owwo, TD Systems; Detect old devices model for brands: AllDocube, Coolpad, Huawei, Vivo,
    Mecool, Sony, Samsung, Sharp, Kyocera, Fujitsu, LG, ZTE, NEC, Freetel, OPPO, Realme, Philips, Hoffmann, GOME,
    Ginzzu, Alcatel, EVOLVEO, Bravis, Condor, Casper, Hisense, Videocon, Walton, IMO, Yu, Own, YEZZ, Nvidia, Medion,
    BQ, Impression, Ulefon, Aligator;
  - #6325 Detect new browser Yaani Browser
  - #6327 Detect new browser: Blue Browser
  - #6332 Detect new brand: Soundmax; Detect old devices model for brand Samsung
  - #6333 Detect new brand: Tone, AT&T, BIHEE, Ravoz and Detect old devices model for brands: Realme, Positivo BGH, Blackview,
    Wiko, Alcatel, Multilaser, Samsung, How, LG, Kyocera, Huawei, Oppo, HTC, Sony, Sharp, Google, Panasonic, ZTE, Coolpad
  - #6335 Logicom Le Hola FR not detected as smartphone, but detected as hola! browser
  - #6336 Fix detect browser: hola! Browser and detect brand Logicom model: Le Hola FR
  - #6337 Update README.md
  - #6338 Adds detection for client DingTalk
  - #6342 Detect new brands: Enot, Kooper, Anry, Tinai and detect devices for existing brands: Thomson, Denver, Highscreen,
    Oppo, O+, Highsense, Lenovo, Cheery Mobile, Unimax and OnePlus
  - #6345 Support for Seobility
  - #6346 Detect notebook devices in Facebook useragents
  - #6347 Detect new brands: Minix, Winds, Asano, MyTab, Phonemax and detect new bot Seobility and Detect devices for
    existing brands: Asus, Aligator, BQ, Bravis, Ergo, HTC, Polaroid, Highscreen, Ulefone, Doodgee and Pixus
  - #6348 Added ReactorNetty library
  - #6352 improved statistics.php report output
  - #6354 Detect new brands: Eltex, Neomi, Lumigon, OzoneHD, Kzen, Melrose, Crony, Takara, Amigoo and Detect devices for
    existing brands: Tecno, Coolpad, Sharp, Sony, Alcatel, BQ, ZTE, Kyocera, Condor, Santin, Own, RugGear, Oukitel,
    Elephone, Vestel, Oysters, MTC, Umax, Echo mobiles, Beeline, Inoi, Wexler, Asus, Samsung, Bitmore, Ulefone, Krüger&Matz,
    Nobby, Highscreen, Xiaomi, Leagoo, Starway, 4Good, MLS, Digma, Irbis, LG, Lenovo, Fujitsu, Advan, Google, Turbo, Ainol,
    Archos, Prestigio, Aligator, Yezz and Detect app: U-Cursos
  - #6357 Detect new brands: Klipad, Tele2, Alfawise, Senkatel, Bobarry, BB mobile, E2, Wortmann, Billion and Detect devices
    for existing brands: Teclast, Alcatel, Assistant, Ace, Ergo, DEXP, Aiwa, Irbis, Datsun, Overmax, Logicom, Ravoz, Asus,
    Blu, Cube, Onda, Oysters, Zidoo, ZTE, Digma, DNS, Sugar, Philips, Ulefone, Fly, Hisense, MicroMax, Brondi, Telefunken,
    Vivax, Yu, Zidoo, Majestic, Leotec
  - #6358 Detect Samsung Galaxy Note 20, Galaxy Note 20 Ultra, and Galaxy Note 20 Ultra 5G
  - #6360 Detect mobile app HeyTabBrowser
  - #6363 Detect devices for existing brands: Samsung, Sony, Phonemax, Casper, DEXP, Nomi, Essentielb, Acer, Digma,
    Tele2, Oukitel, Kyocera, Sharp
  * matomo-org/referrer-spam-list
  - #1225 Update new repository name referrer-spam-list
  - #1229 Add foojo.net to spammers list
  - #1230 Added phimmakinhdi.com
  - #1231 Add suzanneboswell.top
  - #1232 Add briankatrine.top
  - #1233 Added more spammers
  - #1234 Add shcrose.com
- Changes from 3.14.0
  * matomo-org/matomo
  - #16055 Do not load JS tracking code deferred
  - #11071 security ‘forget your password’ prone to phishing attacks
  - #16042 Expose setVisitorId JS tracker method
  - #16193 JS tracker should support CSS class matomo_ignore as alias of piwik_ignore
  - #16189 assign _paq to window in tracking code
  - #15778 Cookie domain config is not applied in ignore cookie preventing opt out to work
  - #16057 Nonce::verifyNonce() returning FALSE when it should not
  - #13056 Add possibility to turn cookies back on, JS enableCookies
  - #13246 ‘requireConsent’ has not effect on cookie setting
  - #15948 Document “How can I still track a visitor without cookies after they declined the cookie consent?”
  - #15955 Do not check if any archive is running when a segment is forced
  - #16006 Removing piwik composer deprecations
  - #16047 Fix falsely assumes session was already started
  - #16069 Add legacy autoloader to support Matomo namespaces in 3.X
  - #16087 wrong escaping of cookie path
  - #16119 Clarify the “password changed” e-mail notification text
  - #13109 Fix 3rd party cookie / global visitorid race condition
  - #16162 GeoLite2-ASN Geolocation not working
  - #13462 Offer possibility to sync JavaScript tracker with any CDN
  * matomo-org/matomo-log-analytics
  - #178 Allow wildcards for importing logs
  - #184 Adds Incapsula log format
  - #222 Add haproxy log format
  - #236 Fix timezone calculation for non-integer timezones
  - #237 Apply config.options.seconds_to_add_to_date to _…ts tracker params
  * matomo-org/device-detector
  - #6140 Can’t detect mobile safari browser version
  - #6182 iPhone OS 12_4 is not browser
  - #6209 Ability to use external source
  - #6303 Detect devices and new browser Quark; Detect new brands: Readme, Sugar, PocketBook, Goophone, Bitmore;
    Detect old brands: Xiaomi, Huawei, Lenovo, Mio, Oppo, CUBOT, Capser, BQ, Backview, Digma, Oysters, Meitu, Odys, Smartisan, Protruly
  - #6308 Detect new brand Xshitou and detect old devices model for brands: Xiaomi, Huawei, Oppo, Gionee, Vivo, Walton, Meizu, Teclast
  - #6310 Added a few Android devices
  - #6312 Detect new brand TWM, Mito, Gree, VKworld, Vodacom, JKL and detect old devices model for brands: Smartisan, OnePlus, OPPO, Vivo, Sharp, Huawei
  - #6316 Improves device detection for mobile apps using chrome
  - #6317 Improves detection for Facebook mobile app
  - #6318 Added a few Android devices
  - #6319 Adds detection for Clout and MLS devices
  - #6320 Detect new brand Contixo, Prixton, Newland, Orbic and detect old devices model for brands: Coolpad, Huawei, Acer, Vivo,
    Meizu, Smartisan, Samsung, HTC, ZTE, Xiaomi, Hisense, Miscrosoft, Sharp, Alcatel, SUGAR, Evercoss
  * matomo-org/referrer-spam-blacklist
  - #1209 Add dreams-works.net
  - #1210 Add nwrcz.com
  - #1211 100searchengines.com should not be listed as referral spam
  - #1212 Added new spammer variant domains
  - #1213 Add brooklynsays.com
  - #1214 Add andrewancheta.com
  - #1215 Add nyinfo.org
  - #1216 Add eduardoluis.com
  - #1217 Add ideayz.com
  - #1218 Add popelina.com
  - #1219 Add iceton.net
  - #1220 Add mybestoffers.club
  - #1221 Add batietiket.com
  - #1223 Add bottraffic4free.club
  - #1226 Adding mycollegereview.com
  - #1227 Added pacobarrero.com
  * matomo-org/matomo-php-tracker
  - #69 Fix include_once warning Failed opening ‘./PiwikTracker.php’ for inclusion
  - #71 Method setRequestMethodNonBulk() added to allow (non bulk) POST requests
  * matomo-org/tracker-proxy
  - #61 rename piwik -> matomo
- Changes from 3.13.6
  Security release
  - In this release we have fixed an non-critical issue in the LDAP plugin.
  * matomo-org/matomo
  - #13655 Limit visitor fingerprint by default for even better privacy
  - #15930 Archive Blob Tables bloating in size
  - #13151 Improve config file and configuration overview in admin
  - #14579 JS Tracker: add rtf to list of downloads
  - #15853 Make sure to increase time limit when archiving
  - #15862 Queue content tracking request
  - #15869 Update visit only when needed
  - #15870 Reexpire archive lock less often
  - #15902 Instagram generates heaps of different referrer urls causing out of memory issues
  - #15954 Fix a plugin that enriches the tracker needed to mark plugin as tracker
  - #15978 Real-time visitors live widget don’t refresh after live_widget_refresh_after_seconds “timed out” without new visits/actions on websites
  - #13783 title-text of JavaScript Tracking option help box shows HTML
  - #15982 Fix: Logo being displayed too small on IE 11
  - #15894 Send onboarding email during installation
  - #15901 Fix Javascript error in JS global template causing side effects
  - #15910 Add link to shopify tracking installation guide when no data tracked yet
  - #12685 Change widget category of Realtime Map to Live!
  - #1931 Translation file cleanups (refactor all html code, commands to type etc.)
  - #13398 undefined method createTestConfig() in BenchmarkTestCase
  - #15883 Updates device detector to 3.12.5
  - #15980 require category and action in logEvent
  - #16015 Fixes some date comparison issues
  - #15111 Load more in Visitor Profile doesn’t load actions
  - #15876 Warning while upgrading “Warning – array_merge(): Argument 2 is not an array”
  - #15881 No Visitors shown in Brandenburg (state of Germany) on the Map
  - #15923 Search engines are displayed in the wrong channel type
  - #15270 Skip password min length checks when disable_checks_usernames_attributes=1
  - #15854 Keep last 100 characters of archive error message when error is too long
  - #15865 Cron – Filesystem.php(430): Warning – filesize(): stat failed for […] archive.sharedsiteids.pid
  - #15867 Fix plugins/Live/Controller.php(99): Notice – Undefined variable: visitors
  - #15879 Minor performance improvement when invalidating archives
  - #15915 Search for links on page load as well, not just on ready
  - #15937 Baidu not considered as a search engine?
  - #15965 Fix theme rewrite removes src attribute when custom plugin directory is used
  - #15997 Fix min archive time not correctly respected
  - #16010 Optional userLogin in getUserPreference API
  * matomo-org/device-detector
  - #6169 Google-HTTP-Java-Client is detected as a bot – correctly?
  - #6244 Adds detection for Light browser
  - #6245 Adds detection for Elements Browser
  - #6248 Adds detection for VMware AirWatch browser
  - #6249 Adds detection for Origin browser
  - #6250 Adds detection for PlayStation 4 Pro console
  - #6251 Add Steam Overlay
  - #6252 Adds detection for Steam browser
  - #6253 Adds detection for AOL Desktop browser
  - #6261 Detect devices and apps; Detect brands: Vivo, Umidigi, Teclast, Huawei, Asus, Irbis, Ergo,
    DEXP, Black Fox, Xiomi, Doogee, Highscreen, NextBook, Ginzzu, Gome, Bravis, Sigma, Qumo, ZTE;
    Detect apps: Snapchat, TopBuzz; Detect new brand: Wigor
  - #6266 Improves detection for Apple iPhone devices
  - #6268 Adds detection for Safe Exam Browser
  - #6269 Improves detection for Avast Secure Browser
  - #6270 Adds detection for Colibri browser
  - #6271 Adds detection for Xvast browser
  - #6272 Adds detection for Tungsten browser
  - #6273 Adds detection for Lulumi browser
  - #6274 Adds detection for Yahoo! Japan Browser
  - #6275 Improves detection for Lunascape browser
  - #6276 Adds detection for Lunascape Lite browser
  - #6277 Adds detection for Jig Browser Plus
  - #6278 Improves detection for Qwant Mobile browser
  - #6279 Adds detection for Polypane browser
  - #6280 Adds detection for Sizzy browser
  - #6281 Adds detection for OhHai Browser
  - #6282 Adds detection for Glass Browser
  - #6283 Improves detection for multiple brands
  - #6284 Adds detection for TmaxOS and ToGate browser
  - #6288 Improves detection for Baidu Browser
  - #6289 Apple Email client is not detecting on v3.12.5
  - #6293 MatomoDeviceDetector.NET is cloned project from totpero/DeviceDetector.NET
  - #6294 Adds detection for new brands Datawind, Droxio, NEXON, ONN, Q.Bell and devices from various existing brands
  - #6295 Update README.md
  - #6297 Add detect Zvu browser
  - #6300 Update README.md
  * matomo-org/referrer-spam-blacklist
  - #1197 Add leddjc.net
  - #1199 Add oudallas.net
  - #1200 add 2 new domains
  - #1201 Add commentag.com
  - #1202 Add estdj.com
  - #1203 Request sites in blacklist
  - #1204 More spammers
  - #1205 Add deryie.com
  - #1206 Add websitebottraffic.host
  - #1207 Add sxsnjj.com
  - #1208 Add websitebottraffic.club
  * matomo-org/searchengine-and-social-list
  - #73 Adds detection for baidu.com (without subdomain)
- Changes from 3.13.5
  * matomo-org/matomo
  - #15831 Archive Blob Tables bloating in size
  - #15545 Deadlock found when trying to get lock
  - #15732 Faster segmented suggested values when browser archiving is disabled
  - #15747 Archiving status: Reexpire lock only when needed
  - #15853 Make sure to increase time limit when archiving
  - #15727 Archiving specific date via console won’t take date as argument.
  - #15750 Fix displaying of actions when loading additional visits in visitor profile
  - #15724 Add possibility to silently stop the archiver without an error
  - #15757 Update device detector to latest 3.12.4
  - #15644 no popup graph shown after the first in page titles report
  - #15740 Pagetitle reports “Page Name not defined” although all PageViews do have a title (action_name)
  - #15764 Realtime visitors “visitsTotal”-div is inserted multiple times
  - #15773 Notifications with the same id might not be shown at all
  - #15784 Force POST for bulk requests, fix alwaysUseSendBeacon not respected for bulk requests
  - #15809 Fix problem when comparing segments or opening popovers
  - #15688 Ensure stringify/parse is a function
  - #15696 Better handling of processing uniques for multiple sites
  - #15729 Codespell report for “Matomo” (on fossies.org)
  - #15746 Fix inconsistent usage of segment idSites
  - #15769 Revert detect page view bucket
  - #15770 One click update in two parts so new code is loaded for second.
  - #15779 Avoid possible error subtable already exists but not loaded
  - #15785 Make sure to always set JSON_PIWIK to native JSON when possible
  - #15798 Make sure to clean up tracking failures before sending email notification
  - #15800 purge all old archives regardless of done value
  - #15808 Add more parameters to the computeNbUnique event
  * matomo-org/device-detector
  - #6170 Problem detecting Twitter App on iOS
  - #6203 Improves detection for Alcatel, Allview, Casper, Condor, Crosscall, Doogee, Lanix, OnePlus, Orange,
    Ulefone, UMIDIGI, Wiko devices
  - #6205 Adds detection for TV Bro Browser and devices of Shift Phones, RugGear, Aligator, Maxcom, Luna and some existing brands
  - #6206 Adds detection for Oukitel devices
  - #6207 Adds detection for Ace device
  - #6210 Santin BiTBiZ incorrect brand name
  - #6211 Fix brand Santin name and added other models
  - #6215 What type of device to use in motamo? if the device is a smartwatch
  - #6216 Adds detection for Razer device
  - #6217 Detect devices for brands: iBall, Irbis, Motorola, Huawei, Casper, Qysters, Protruly, RegGear, Runbo, Telefunken, JFone,
    Ritmix, IconBIT, Samsung, LG, Acer, Assistant, Vonino, UMIDIGI, Philips, Krüger&Matz, Uhans, Overmax, ArmPhone
  - #6218 Adds detection for Goanna browser engine
  - #6219 Adds detection for Amazon devices
  - #6220 Adds detection for Grundig devices
  - #6221 Adds detection for Insignia devices
  - #6222 Adds detection for Element device
  - #6226 Add surf browser
  - #6229 Adds detection for XenForo service agent
  - #6231 Update README.md
  - #6232 Adds detection for Google Duplex on the Web bot
  - #6234 Adds detection for GTmetrix crawler
  - #6235 Tests run failed for another lib matthiasmullie\scrapbook\src\Adapters\MemoryStore
  - #6236 Adds detection for new brands iGet, Soyes, Zfiner and Zidoo and some other devices
  - #6239 Adds detection for new brands iVa, Phicomm, Gome, Voyo, Huadoo, Ryte, Vontar and some other devices
  - #6240 Adds detection for Mypal browser
  - #6241 Adds detection for Centaury browser
  - #6242 Adds detection for Arctic Fox browser
  - #6243 Fix Basilisk browser rendering engine
  - #6246 Adds detection for Atom browser
  - #6247 Improves detection for Avast Secure Browser
  - #6254 Adds detection for 115 Browser
  - #6257 Detect mobile app Twitter
  - #6258 Add support for AspiegelBot, a new Huawei spider
  * matomo-org/referrer-spam-blacklist
  - #1189 add celestepage.xyz
  - #1190 Four more Referrerspammer
  - #1192 More spammers
  - #1193 Add ptfic.org
  - #1194 Remove from list vk.com
  - #1195 Update spammers.txt
  - #1196 Add sneakerfreaker.com
  * matomo-org/tag-manager
  - #235 Fix possible error on PHP 7.4
* Sat Mar 28 2020 ecsos@opensuse.org
- Update to 3.13.4
  This release is rated moderate security release.
  - Fix a a possible XSS issue.
  * matomo-org/matomo
  - #15625 ‘Remember me’ not working because cookie expire is in wrong format [by @sgiehl]
  - #15598 Set samesite lax instead of None if site is not on https [by @tsteur]
  - #15623 Mention require PHP 7.2 in admin notification [by @sgiehl]
  - #15588 slow SQL query using MariaDB causing high CPU load [by @sgiehl]
  - #15609 Limit max execution time of transitions feature [by @sgiehl]
  - #15616 Review Archive invalidation code [by @diosmosis]
  - #15646 Today archive is invalidated too often [by @diosmosis]
  - #14694 Warning – ucwords() expects exactly 1 parameter, 2 given [by @katebutler, @sgiehl]
  - #14764 Page Overlay stuck on “Loading…”
  - #15589 [Geo] Unknown region metrics increased significantly after update to v3.13.1
  - #15629 Using Opt-Out iFrame twice doesn’t work [by @sgiehl]
  - #15637 Ecommerce Orders Conversion Rate Rounding Error [by @sgiehl]
  - #15550 Notice: Trying to access array offset on value of type null in
    core/Session/SessionAuth.php on line 63 [by @diosmosis]
  - #15651 Prevent connection timed out when requesting configs.php file on IIS in web.config
  - #15672 There is no way to enable ‘secure’ for the 3rd party cookie [by @tsteur]
  - #15580 Geolocation: automatically download latest paid DB-IP databases [by @sgiehl]
  - #15614 Remove donation widget from dashboard [by @tsteur]
  - #15665 Convert range date to date archive if needed [by @tsteur, @sgiehl]
  - #15673 Always send a referrer-policy header [by @polarbirke, @diosmosis]
  - #15684 Retry compiling less file if it fails [by @tsteur, @diosmosis]
  - #15686 Prevent notice in PHP 7.4 Passing glue string after array is deprecated
  - #15687 Make sure config cache is only used when there is a correct path
  - #15707 Detect page view bucket [by @tsteur]
  * matomo-org/device-detector
  - #6174 Oppo devices not detected (new useragent list & model names)
  - #6176 Detect devices for brands: Asus, Oppo, Huawei, Sony, Lenovo, LG, Wiko, Nuvo, Alcatel,
    Irbis, Heair, Motorola, CoolPad, Sunvell, AllDocube, Assistant, DEXP, ZTE, CAT, Xiaomi,
    Google, Yandex, Hisense, T-Mobile, Allview, ViewSonic, Yxtel, Ginzzu, HTC
  - #6178 Add Java port to README.md [by @mngsk, @sgiehl]
  - #6181 Add ScalaJ HTTP library [by @wallin, @sgiehl]
  - #6183 Detection of Google Stackdriver Monitoring [by @Pierre-Lannoy, @sgiehl]
  - #6184 Detection for Google Cloud Scheduler [by @Pierre-Lannoy, @sgiehl]
  - #6185 Car tablet CarPad
  - #6186 Panasonic Lumix DMC-CM1
  - #6189 feat(device) detect new brand NewsMy & CarPad 2, CarPad 3; [by @sanchezzzhak, @sgiehl]
  - #6191 Detect devices for brands: Wiko, Oysters, Pixus, Cherry Mobile, Vivo, EvroMedia,
    Allview, ZTE, Lenovo, Kiwi, Spectrum, Vesta, Ritmix, Casper, NUU, Ginzzu, Telefunken,
    National, Kaiomy, Kanji [by @sanchezzzhak, @sgiehl]
  - #6195 Added Node Fetch library [by @wallin, @sgiehl]
  - #6198 Adds detection for Samsung devices [by @liviuconcioiu, @sgiehl]
  - #6200 Adds detection for iHunt devices [by @liviuconcioiu, @sgiehl]
  - #6201 Adds detection for Allview devices [by @liviuconcioiu, @sgiehl]
  - #6202 Adds detection for Wiko devices [by @liviuconcioiu, @sgiehl]
  * matomo-org/referrer-spam-blacklist
  - #1181 More spammers [by @AaronVanGeffen, @spmedia]
  - #1182 Add greentechsy.com [by @ericguirbal, @spmedia]
  - #1184 Add ingramreed.xyz [by @ericguirbal, @spmedia]
  - #1185 Add janemill.xyz [by @ericguirbal, @spmedia]
  - #1186 More spammers [by @AaronVanGeffen, @spmedia]
  - #1187 Add sabinablog.xyz [by @ericguirbal, @spmedia]
  - #1188 Add martinahome.xyz [by @ericguirbal, @spmedia]
  * matomo-org/tag-manager
  - #229 Set samesite flag (used in “preview mode” in tag manager container)
  - #232 Remove duplicate index in variables table [by @tsteur]
  * matomo-org/matomo-php-tracker
  - #60 Prevent double slashes [by @tsteur, @sgiehl]
  * matomo-org/matomo-log-analytics
  - #180 Improve regex for date and time in w3c formats [by @sgiehl]
* Mon Feb 24 2020 Lars Vogdt <lars@linux-schulserver.de>
- Update: 3.13.3
  In this new release we’re solving a few regressions and making a
  few minor improvements. In terms of bugs, an issue in the Overlay
  report causing sessions to logout has been fixed.
  Other issues were fixed the Samesite cookies handling and session,
  and a bug was fixed in the new Date comparison feature.
  [#15513] Loading Page Overlay fails and logs user out [by @diosmosis]
  [#15602] Fix session cookies for Matomo installed in subdirectory
  [by @sgiehl, @tsteur]
  [#15605] Fix VisitorFrequency.get API for idsites=all [by @sgiehl]
  [#15553] piwik_ignore cookie is blocked on macOS and Chrome 80 [by @diosmosis]
  [#15561] Various fixes for Samesite handling in sessions,
  iframes [by @diosmosis, @tsteur]
  [#15568] Support tracker js files from custom plugin directories [by @tsteur]
  [#15569] Fix non-numeric value encountered in session recording [by @tsteur]
  [#15576] Do not record the stack trace for user input errors [by @tsteur, @sgiehl]
  [#15577] During archive invalidation clear general cache less often [by @tsteur, @diosmosis]
  [#15590] Fallback to JSON renderer if no valid format is given [by @tsteur]
  [#15592] Try to determine the region iso code based on its name if
  not available [by @sgiehl, @tsteur]
* Tue Feb 18 2020 Lars Vogdt <lars@linux-schulserver.de>
- Update: 3.13.2
  In this release we’re focusing on fixing a few minor bugs and two
  regressions that were introduced in the last release
  (tracking IE<9 was not working anymore, and automatic login within
  an iframe has also been fixed).
  41 tickets have been closed by more than 12 contributors!
  Main (core) tickets closed:
  [#15404] Real time map dialog box does not close with x [by @sgiehl]
  [#8505] Visitor map shows info icon but no tooltip when there is no data [by @sgiehl]
  [#15414] Since 3.13.1 autologin in an iframe does not work anymore [by @tsteur]
  [#15422] Fix removing user capabilities [by @sgiehl, @tsteur]
  [#15477] Matomo can’t track IE <9 any more [by @tsteur]
  [#15500] Undefined index: bounce_rate_new [by @sgiehl]
  [#15417] In Update pop up venster Piwik is mentioned instead of Matomo [by @sgiehl]
  [#14549] update mocha
  [#15469] Two YAML parser
  [#15307] Visits log fails without any error [by @tsteur]
  [#15420] Cannot copy a dashboard to a user when the user is not one of
    the first 100 [by @sgiehl]
  [#15430] VisitorLog.php(225): Trying to access array offset on value
    of type null – Matomo 3.13.1 [by @sgiehl]
  [#15441] UserId.getUsers generates warnings: Warning – Illegal
    offset type and Notice – Undefined index: label [by @sgiehl]
  [#15452] Trying to access array offset on value of type null [by @sgiehl]
  [#15046] Clarify how to Setup the archiving cronjob using Plesk in the user guide manual
  [#15293] New visit not created after logout
  [#15428] Order of implode() args, avoid E_NOTICE in PHP7.4 [by @PeterUpfold, @sgiehl]
  [#15445] Forward instance_id from local config when reseting config
    during tests. [by @diosmosis]
  [#15446] silence is_executable call in case user doesn’t have permission
    to access dir [by @diosmosis]
  [#15457] Add event that allows plugins to disable archiving for certain
    periods/sites if they want. [by @diosmosis]
  [#15462] Day range archiving issue [by @diosmosis, @tsteur]
  [#15464] Use latest davaxi/sparkline release [by @sgiehl]
  [#15481] Mention Joomla install FAQ [by @tsteur, @diosmosis]
  [#15487] Sort Packages [by @limitstudios, @tsteur]
  [#15489] Make sparklines work when mbstring extension is not installed
    [by @mattab, @diosmosis]
- pre-require php-json to make sure the post script works
* Mon Feb  3 2020 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(systemd) instead of systemd: allow OBS to
  shortcut through the -mini flavors.
* Sat Jan 18 2020 Lars Vogdt <lars@linux-schulserver.de>
- Update: 3.13.1
  In this release we’re focusing on fixing a few bugs, a regression in tracking
  unique visitors affecting some users, we’re making Matomo tracking slightly
  faster, and we ensure compatibility with the upcoming Chrome 80 browser.
  + This release is also rated critical and includes a major security fix.
  + A regression was introduced in 3.13.0 which could in some cases lead
    to inflate unique visitors/unique users metrics, when the User ID
    feature is used: this regression has been fixed.
  + Another regression causing some of the number metrics to display
    wrongly in some languages such as German has been fixed.
  + As the default geolocation provider MaxMind is introducing new
    complicated licensing terms for their geolocation database, and
    broke auto-updating of geolocation databases for Matomo, we’re
    introducing a new Geolocation provider by default to replace MaxMind.
    Matomo will now use db-ip.com as a geolocation provider and all
    Matomo users will automatically download this new geolocation
    database starting in 3.13.1.
  + Chrome 80 is planning to make all cookies that don’t have an explicit
    `SameSite` option have `SameSite=Lax` by default. So far it has been
    an optional flag but Chrome 80 (release due in January 2020) will have
    it enabled by default.
    Matomo 3.13.1 will be fully compatible and won’t issue a browser
    console warning anymore.
  + The Countries Regions maps should now work again and display data
    for most countries regions.
  + In terms of new features, we’ve improved the Behaviour > Engagement report,
    which will now clearly display all metrics for both Returning visits and
    New visits
* Mon Dec 23 2019 Lars Vogdt <lars@linux-schulserver.de>
- (add) more secure PHP settings for:
  upload_tmp_dir => "/var/cache/apache2" (upload is disabled, but this
    makes Matomo's security check happy)
  session.save_path => "/run/matomo_sessions/", to keep session files
    secure. Added: matomo-tmpfile.conf for this
- just recommend cron and mariadb:
  * mariadb can be run on another host (matomo just needs the client)
  * cron script can be obsoleted by the provided systemd timer
- pre-require php, to run the commands in post
- recommend php-openssl for (php) curl requests from matomo
* Thu Dec 12 2019 Lars Vogdt <lars@linux-schulserver.de>
- moved the update message in post to the right position
- disable some (unused) php functions
- use open basedir
- add newly required php modules:
  php-ctype, php-dom, php-iconv, php-tokenizer, php-xmlreader,
  php-xmlwriter, php-zlibm
- define locations of web-, log- and config directories dynamically
- allow to enable compression
- enhanced README.SUSE
* Thu Dec 12 2019 Mathias Homann <Mathias.Homann@opensuse.org>
- Update: 3.13.0
  * matomo-org/matomo
    [#15030] Adds links to online guides in reports help [by @sgiehl, @diosmosis]
    [#4519] Segment by Product Category, Product name, Product SKU, Product prices [by @diosmosis]
    [#15049] More efficient heart beat timer [by @tsteur]
    [#10439] After updating the 2019_01 archive blob tables are gaining size [by @diosmosis]
    [#15086] Auto Archiving falls back to DEFAULT_DATE_LAST even if last archiving ran until completion [by @katebutler, @diosmosis]
    [#10765] Write a User guide for Custom alerts [by @mattab]
    [#14835] Page Overlay – JavaScript Error – TypeError: location.match(…) is null [by @diosmosis]
    [#15101] Matomo 3.12.0 missing Action in Proxy module
    [#15044] Slight performance improvement when rendering data table visualisations [by @tsteur, @diosmosis]
    [#15000] _pk_testcookies set while using “disableCookies” [by @tsteur]
    [#15070] Matomo 3.12 doesn’t work with open_basedir restrictions [by @tsteur]
    [#15078] Integrity check issue in Matomo 3.12.0
    [#15093] Fix reports by dimensions layout [by @sgiehl, @diosmosis]
    [#15102] Fix Insight visualization layout [by @sgiehl, @tsteur]
    [#15151] E-Mail reports date range error [by @diosmosis]
    [#14945] In Comparison mode, numbers are not formatted (thousands separator) [by @katebutler]
    [#14821] Make Matomo compatible with PHP 7.4 [by @diosmosis]
    [#10373] Excluding IPs doesn’t work on php7
    [#14623] Update message creates empty space in admin and pushes widgets down
    [#14714] JS Tracker: setUserId and addEcommerceItem sku should work when User ID is a number [by @tsteur]
    [#15080] Comparison feature displays segment definition instead of segment name when segmenting action based custom dimensions [by @diosmosis]
    [#15103] Ensure insight reports uses the correct compare period number for periods other than day [by @sgiehl, @tsteur]
    [#15140] [automatic translation update] Updated 173 strings in 10 languages (es-ar, de, el, nl, pl, pt-br, pt, sq, zh-cn, zh-tw) [by @sgiehl]
    [#15195] [automatic translation update] Updated 160 strings in 6 languages (fr, it, ja, lt, pt-br, tr) [by @sgiehl]
    [#12816] Rename “Clicked URL” dimension to “Clicked Outlink” [by @katebutler]
    [#14360] UserID no longer overwrites VisitorId [by @MichaelHeerklotz, @diosmosis]
    [#14827] German title HTML entity encoded [by @sgiehl]
    [#15026] Use thousands separator in single metric view [by @katebutler, @tsteur]
    [#15032] Some overlay improvements [by @tsteur, @diosmosis]
    [#15037] Prevent warning array to string conversion in console renderer [by @tsteur, @diosmosis]
    [#15055] Updates device detector to 3.12.1 [by @sgiehl, @diosmosis]
    [#15057] Prevent notice in tracker code generator [by @tsteur, @diosmosis]
    [#15066] Avoid ‘Trying to add two strings in DataTable\Row::sumRowArray’ warning in SEO API [by @sgiehl, @diosmosis]
    [#15079] Revert umlaut icons [by @Findus23, @tsteur]
    [#15087] 3.12.0 (3.12.0-b4 and up) is broken on NixOS
    [#15088] Rename “Clicked URL” dimension to “Clicked Outlink” [by @katebutler, @diosmosis]
    [#15090] Made a few minor grammar changes to the README.md [by @ALucatero03, @tsteur]
    [#15095] Fix zend session hides actual error when there are two or more errors… [by @tsteur]
    [#15098] Invert change comparison when displaying percents in the UI … [by @diosmosis]
    [#15110] Fixes a couple segment handling regressions in the UI [by @diosmosis]
    [#15113] Document that Matomo won’t work with a MySQL load balancer such as ProxySQL unless… [by @mattab]
    [#15114] Better detection of a succesfull start of a session [by @tsteur, @diosmosis]
    [#15116] Show the link to upload a new plugin when enable_plugin_upload=1 [by @mattab, @diosmosis]
    [#15129] Don’t freeze lefthand column of datatable on small screens [by @katebutler, @tsteur]
    [#15147] Adds new event to define if lower metric values are better [by @sgiehl, @tsteur]
    [#15152] Fix manual plugin upload process when Marketplace plugin is disabled [by @diosmosis, @tsteur]
    [#15165] Update FAQ “How do I measure and get reports for my page sections / categories / mini-sites / languages?” to reflect how segment now work [by @tsteur]
    [#15166] Fix socket configuration not applied in MySQLi [by @tsteur, @diosmosis]
    [#15178] API reference doc: fix some of the example links [by @mattab, @diosmosis]
    [#15183] Update spyc to 0.6.X [by @tsteur]
    [#15187] Fix broken dashboard when a new version available and when multi_server_environment = 1 [by @mattab, @diosmosis]
    [#15189] Support CliMulti on OS X and print note about whether CliMulti is used in archive output [by @diosmosis]
  * matomo-org/device-detector
    [#5797] Did not catch “The Knowledge AI”
    [#6070] Add 7 new crawlers and 3 feed readers [by @Kdecherf, @sgiehl]
    [#6078] add new rules and tests for Nokia/Microsoft devices [by @mimmi20, @sgiehl]
    [#6081] Detect devices for brands: Samsung, Vivo, iHunt, Huawei, Ritmix, Ross&Moor [by @sanchezzzhak, @sgiehl]
    [#6083] Fail to Detect Meitu Device
    [#6084] Added detect devices Meitu [by @sanchezzzhak, @sgiehl]
    [#6085] Adds detection for Yandex Browser Lite and improves version detection for Yandex Browser [by @liviuconcioiu, @sgiehl]
    [#6086] Adds detection for Shopify Partner bot [by @liviuconcioiu, @sgiehl]
    [#6087] Added RestSharp library [by @wallin, @sgiehl]
    [#6088] Improves detection for Vonino devices [by @liviuconcioiu, @sgiehl]
    [#6092] Fix detection for AIS [by @liviuconcioiu, @sgiehl]
    [#6093] Adds detection for Servo browser engine [by @liviuconcioiu, @sgiehl]
    [#6096] Not Detecting OnePlus 7 Pro
  * matomo-org/component-network
    [#4] Function getIPRangeBounds doesn’t always work on php7 [by @tsteur]
    [#10] Validate CIDR range is 0..32 (IPv4) or 0..128 (IPv6); ref RFC-4632 [by @robocoder, @tsteur]
    [#12] Test enhancement [by @peter279k, @tsteur]
    [#13] Improving tests for IP class [by @peter279k, @tsteur]
  * matomo-org/tracker-proxy
    [#57] Test enhancement [by @peter279k, @tsteur]
  * matomo-org/tag-manager
    [#176] Adjustments for using TM and classic Tracking Code at the same time [by @MichaelHeerklotz, @tsteur]
    [#184] Do not regenerate containers after core archiving [by @tsteur]
    [#197] Use matomo.js and matomo.php as default if preferred [by @tsteur]
    [#198] Convert empty date to null [by @tsteur]
    [#199] fix: Tag::updateContainerTag setting a wrong startDate and endDate value [by @lockland, @tsteur]
    [#202] Fix first trigger callback when tracker js is already loaded [by @MichaelHeerklotz, @tsteur]
  * matomo-org/matomo-log-analytics
    [#251] Clarified usage of –token-auth=<SECRET> [by @cedwardsmedia, @tsteur]
  * matomo-org/matomo-php-tracker
    [#44] Unlink userId and visitorId logic [by @MichaelHeerklotz, @diosmosis]
    [#48] Fix wrong tracking url generated if tracker API endpoint already contains query search [by @tsteur, @diosmosis]
    [#50] Regression: Wrong header is enabled only for GET. [by @diosmosis]
  * matomo-org/referrer-spam-blacklist
    [#1143] Add 033nachtvandeliteratuur.nl [by @ericguirbal, @spmedia]
    [#1145] Add 350+ spammer in bulk [by @Zodiac1978, @spmedia]
    [#1146] Block billyblog.online [by @jonhenshaw, @spmedia]
    [#1147] Update spammers.txt [by @spmedia]
    [#1148] Add tammyblog.online [by @ericguirbal, @spmedia]
    [#1149] Block monicablog.xyz [by @jonhenshaw, @spmedia]
  * matomo-org/component-ini
    [#11] Test enhancement [by @peter279k, @tsteur]
    [#12] Problem about IniReader::getFileContent method implementation
* Thu Oct 31 2019 Mathias Homann <Mathias.Homann@opensuse.org>
- js folder needs to be RW for the tag manager plugin
* Wed Oct 30 2019 Mathias Homann <Mathias.Homann@opensuse.org>
- Fixed unsafe permissions for directory js
- Fixed permissions for piwik.js, matomo.js and js/piwik.min.js
* Wed Oct 30 2019 ecsos@opensuse.org
- Fix wrong permission for directory js.
- Use original source file.
* Wed Oct 30 2019 Mathias Homann <Mathias.Homann@opensuse.org>
- piwik.js needs to be writable, too
* Wed Oct 30 2019 Mathias Homann <Mathias.Homann@opensuse.org>
- more permission fixes
  * matomo.js needs to be owned by the apache user so that plugins can
    rewrite it if required
  * new md5sum for global.ini.php
* Wed Oct 30 2019 Mathias Homann <Mathias.Homann@opensuse.org>
- disabled the auto updater, doesn't work with this set of permissions
* Wed Oct 30 2019 Mathias Homann <Mathias.Homann@opensuse.org>
- Update to 3.12.0
  * new comarison feature for date ranges and visitor segments
  * several significant performance improvements, usability improvements and fixes to security issues
  * full changelog is at https://matomo.org/changelog/matomo-3-12-0/
* Mon Oct 21 2019 Mathias Homann <Mathias.Homann@opensuse.org>
- Security fix: BSC#1154324
  * Have as little as possible owned by, and writable for, the apache user
* Thu Jul 25 2019 ecsos@opensuse.org
- Update to 3.11.0
  This release includes security improvements (including a security
  fix) and also several performance improvements and bug fixes.
  Details: https://matomo.org/changelog/matomo-3-11-0/
- Fix fileintegritycheck under systemcheck.
* Thu Jul  4 2019 ecsos@opensuse.org
- Insert configuration for mariadb.
- Add missing htaccess rules.
* Tue Jul  2 2019 ecsos@opensuse.org
- Update to 3.10.0
  * Breaking Changes
  - When giving a user superuser access through the
    UsersManager.setSuperUserAccess API, a new parameter
    passwordConfirmation needs to be sent along with the request
    containing the current password of the user issuing the API
    request.
  - Website referrer URLs are now detected using domain only
    instead of domain and path. This means if you have two
    different websites on the same domain, but different paths,
    and a visitor visits from one to the other, it won't have
    a referrer website set.
  - Custom Dimensions values set with setCustomDimension are now
    URL encoded (they previously weren't). If you were manually
    URL encoding the custom dimension values before calling
    setCustomDimension, your custom dimension values appearing in
    reports and Visits log/Visitor profile may now be double URL
    encoded. To solve the double encoding issue, you can remove
    your URL encoding and trust that Matomo JavaScript Tracker
    will URL encode the values correctly.
  * New APIs
  - A new tracker method ping has been added to send a ping
    request manually instead of using the heart beat timer.
  - Added new event ViewDataTable.configure.end, triggered after
    view configuration properties have been overwritten by saved
    settings and query parameters.
* Fri Mar 22 2019 Mathias Homann <Mathias.Homann@opensuse.org>
- Update to 3.9.1
  * This release addresses a couple of issues and errors discovered
    in Matomo 3.9.0. 4 tickets have been closed by 2 contributors.
  - #14229 Notice – unserialize(): Error at offset 0 of 53988
    bytes
  - #14226 open_basedir restriction AND Support multiple plugin
    paths [by @sgiehl]
  - #14227 One-click upgrade sometimes fails with errors such as
    “Call to undefined method
    Piwik\Plugin\Manager::getPluginDirectory() ”
    (fails only once, works after a refresh)
  - #14240 Do not send password changed email for automated use
    cases. [by @diosmosis, @sgiehl]
* Wed Mar 20 2019 ecsos@opensuse.org
- Update to 3.9.0
  * Breaking Changes
  - Referrers.getKeywordsForPageUrl and
    Referrers.getKeywordsForPageTitle APIs have been deprecated
    and will be removed in Matomo 4.0.0
  - By default, Matomo application logs will now be logged in
    tmp/logs/matomo.log instead of tmp/logs/piwik.log. This log
    file path can be edited in your config/config.ini.php in
    the INI setting logger_file_path.
    Not relevant for this suse package.
  * New Features
  - It is now possible to locate plugins in a custom directory
    by setting an environment variable MATOMO_PLUGIN_DIRS or a
    ['MATOMO_PLUGIN_DIRS'] variable in /bootstrap.php.
  - It is now possible to use monolog's FingersCrossedHandler
    which buffers all logs and logs all of them in case of
    warning or error.
  * New APIs
  - New API methods Piwik\Plugin\Manager::getPluginsDirectories()
    and Piwik\Plugin\Manager::getPluginDirectory() have been
    added as it is now possible to locate Matomo plugins in
    different directories and it should be no longer assumed
    a plugin is located in the /plugins directory.
  - A new tracker method disableQueueRequest has been added to
    disable queued requests which may be useful when logs are
    imported.
  - The event LanguageManager.getAvailableLanguages has been
    deprecated. Use LanguagesManager.getAvailableLanguages
    instead.
* Tue Jan 29 2019 ecsos@opensuse.org
- Update to 3.8.1
  This release addresses a few minor issues discovered in 3.8.0 and
  a few improvements were also added.
  Detail changelog see: https://matomo.org/changelog/matomo-3-8-1/
* Thu Jan 24 2019 ecsos@opensuse.org
- Fix paths in cron and service file.
* Tue Jan 22 2019 ecsos@opensuse.org
- Update to 3.8.0
  This is an update and security release.
  Detail changelog see: https://matomo.org/changelog/matomo-3-8-0/
* Tue Nov 27 2018 ecsos@opensuse.org
- Remove %%config from service files. Changes must not do in system
  location, user must do this changes in /etc/systemd/system.
* Thu Nov 22 2018 Jan Engelhardt <jengelh@inai.de>
- Join %%service_* calls, find calls, everything that iterates
  (except for fdupes, where /usr files naturally should be
  separated from /srv).
- Require user/group package.
* Tue Nov 20 2018 ecsos@opensuse.org
- Update to 3.7.0
  This is an update and security release.
  Detail changelog see: https://matomo.org/changelog/matomo-3-7-0/
* Sat Nov 17 2018 ecsos@opensuse.org
- Remove verification for systemd
- Add systemd-timer for auto archiving of reports.
  Now you can use cron or systemd.timer.
- Add core:update during update of package
- Add logrotate
- Add rpmlintrc
- Upgrade README.SUSE
* Fri Oct 19 2018 ecsos@opensuse.org
- update to 3.6.1
  [#] New APIs
  * Added new event `Access.modifyUserAccess` which lets plugins
    modify current user's access levels/permissions.
  * Added new event `CustomMatomoJs.manipulateJsTracker` which
    lets plugins modify the JavaScript tracker.
  [#] New Developer Features
  * Logging to a file can now be easily enabled during tests.
    A new `[tests] enable_logging` INI option has been added,
    which you can set to `1` to enable logging for all tests.
    The `tests:run` and `tests:run-ui` commands now both have an
    `--enable-logging` option to enable logging for a specific
    run.
* Thu Aug 30 2018 ecsos@opensuse.org
- update to 3.6.0
  This a update and security release.
  [#] New Features
  * A new role has introduced called "write" which has less
    permissions than an admin but more than a view only user
    (see FAQ).
  * Custom currencies can now be added using the currencies[]
    configuration key.
  * A new segment eventValue lets you select all users who
    tracked a custom event with a given value or range of values.
  [#] New config.ini.php settings
  * archiving_profile = 0, if set to 1, core:archive profiling
    information will be recorded in a log file. the log file is
    determined by the archive_profiling_log option.
  * archive_profiling_log =, if set to an absolute path,
    core:archive profiling information will be logged
    to specified file.
  * enable_internet_features=0 will now fully disable Internet
    access by preventing all outgoing connections. Note: changing
    this setting is not recommended for security, because you
    will lose the easy auto-update and email notifications.
  * login_whitelist_ip[] now supports hostnames so you can
    whitelist your IP addresses and/or Hostnames and keep your
    Matomo secure.
  [#] Updated commands
  * New parameter --concurrent-archivers to define the number of
    maximum archivers to run in parallel on this server.
    Useful to prevent archiving processes piling up and
    ultimately failing.
  [#] New APIs
  * Added new event API.addGlossaryItems which lets you add items
    to the glossary.
  * Added new event Tracker.detectReferrerSocialNetwork which
    lets you add custom social network detections
  * Added new event Report.unsubscribe which is triggered
    whenever someone unsubscribe from a report
  * Added new API method UsersManager.getAvailableRoles to fetch
    a list of all available roles that can be granted to a user.
  * Added new API method UsersManager.getAvailableCapabilities to
    fetch a list of all available capabilities that can be
    granted to a user.
  * Added new API method UsersManager.addCapabilities to grant
    one or multiple capabilities to a user.
  * Added new API method UsersManager.removeCapabilities to
    remove one or multiple capabilities from a user.
  * The API method UsersManager.setUserAccess now accepts an
    array to pass a role and multiple capabilities at once.
  * Plugin classes can overwrite the method
    requiresInternetConnection to define if they should be
    automatically unloaded if no internet connection is available
    (enable_internet_features = 0)
  * Added two new methods to the JS tracker: removeEcommerceItem
    and clearEcommerceCart to allow better control over what is
    in the ecommerce cart.
  * Tracking API requests now include &consent=1 in the Tracking
    API URL When consent has been given by a user.
  [#] Breaking Changes
  * Changed some menu items to use translation keys instead
    (see PR #12885).
  * The methods assertResponseCode() and assertHttpResponseText()
    in Piwik\Tests\Framework\TestCase\SystemTestCase have been
    deprecated and will be removed in Matomo 4.0. Please use
    Piwik\Http instead.
  * The classes PHPUnit\Framework\Constraint\HttpResponseText
    and PHPUnit\Framework\Constraint\ResponseCode have been
    deprecated and will be removed in Matomo 4.0. Please use
    Piwik\Http instead.
  * Creating links through the Proxy has been deprecated.
    Use rel="nofollow" instead.
  * The console option --piwik-domain has been deprecated and
    will be removed in Matomo 4.0. Use --matomo-domain instead
  * Social networks are now detected as new referrer type (ID=7),
    which allows improved reports and better segmentation
  * New settings form field UI component "Field Array" that lets
    users enter multiple values for one setting as a flat array
* Sat May 26 2018 ecsos@opensuse.org
- update to 3.5.1
  [#] New APIs
  * Added new method Piwik\API\Request::isRootRequestApiRequest()
    to detect if the root request is an API request.
* Wed May  9 2018 ecsos@opensuse.org
- update to 3.5.0
  [#] Breaking Changes
  * Flattened action url reports now always include a leading `/`
    and will no longer include the `default_action_name`.
    e.g. `path/to/index` will now be `/path/to/`.
    This might affect configured custom alerts, as this plugin
    uses the flattened url reports for comparison.
  [#] New APIs
  * New JavaScript tracker functions to [ask for consent]
    (https://developer.matomo.org/guides/tracking-javascript-
    guide#asking-for-consent): `requireConsent`,
    `rememberConsentGiven`, `setConsentGiven`,
    `forgetConsentGiven`.
  * New events `PrivacyManager.deleteLogsOlderThan`,
    `PrivacyManager.exportDataSubjects` and
    `PrivacyManager.deleteDataSubjects` to enable plugins to be
    GDPR compliant.
  * New event `AssetManager.addStylesheets` to add additional
    less styles which are not located in a file.
  * New event `Archiving.getIdSitesToMarkArchivesAsInvalidated`
    that lets plugins customize the behaviour of report
    invalidations.
  * Reports and visualizations can now disable the 'all' rows
    limit selector:
    `$view->config->disable_all_rows_filter_limit`.
  * New settings form field UI component "Multi Tuple" that
    lets users enter multiple values for one setting
  Detail changelog see: https://matomo.org/changelog/matomo-3-5-0/
* Sun Apr  8 2018 ecsos@opensuse.org
- update to 3.4.0
  - `piwik` font is deprecated and will be removed in Matomo 4.0.
    Please use new `matomo` font instead
  - New APIs
  See https://matomo.org/changelog/matomo-3-4-0/
* Thu Feb  8 2018 jengelh@inai.de
- Ensure neutrality of description.
- Fix unknown RPM category group.
- Replace old $RPM_ variables with macros.
- Avoid %%__-type macro indirections.
- Do not let fdupes cross partitions.
* Sat Jan 13 2018 ecsos@opensuse.org
- Branch package from piwik,
  because piwik renamed to matomo.
- update to 3.3.0
  See https://matomo.org/changelog/matomo-3-3-0/
* Thu Dec  7 2017 ecsos@opensuse.org
- update to 3.2.1
  see https://piwik.org/changelog/piwik-3-2-1/
* Fri Oct 13 2017 ecsos@opensuse.org
- update to 3.2.0
  see https://piwik.org/changelog/piwik-3-2-0/
* Thu Sep 21 2017 ecsos@opensuse.org
- update to 3.1.1
  see https://piwik.org/changelog/piwik-3-1-1/
* Tue Sep 12 2017 ecsos@opensuse.org
- update to 3.1.0
  This release is rated important, two XSS issues have bin fixed.
  Also 120 tickets closed.
  see https://piwik.org/changelog/piwik-3-1-0/
* Tue Aug 15 2017 ecsos@opensuse.org
- fix spec to use php7 too
* Tue Aug 15 2017 ecsos@opensuse.org
- fix errors in piwik.conf
* Thu May 18 2017 ecsos@opensuse.org
- update to 3.0.4
  see https://piwik.org/changelog/piwik-3-0-4/
* Wed Apr  5 2017 ecsos@opensuse.org
- update to 3.0.3
  see https://piwik.org/changelog/piwik-3-0-3/
* Fri Mar  3 2017 ecsos@opensuse.org
- update to 3.0.2
  see https://piwik.org/changelog/piwik-3-0-2/
* Tue Jan 10 2017 ecsos@opensuse.org
- update to 3.0.1
  see https://piwik.org/changelog/piwik-3-0-1/
* Tue Dec 20 2016 ecsos@opensuse.org
- update to 3.0.0
  see https://piwik.org/changelog/piwik-3-0-0/
* Tue Nov 15 2016 ecsos@opensuse.org
- update to 2.17.1
  see https://piwik.org/changelog/piwik-2-17-1/
* Fri Oct 28 2016 ecsos@opensuse.org
- update to 2.17.0
  see https://piwik.org/changelog/piwik-2-17-0/
* Wed Oct  5 2016 ecsos@opensuse.org
- update to 2.16.5
  see https://piwik.org/changelog/piwik-2-16-5/
* Tue Oct  4 2016 ecsos@opensuse.org
- update to 2.16.4
  see https://piwik.org/changelog/piwik-2-16-4/
* Tue Oct  4 2016 ecsos@opensuse.org
- update to 2.16.3
  see https://piwik.org/changelog/piwik-2-16-3/
  - This is a security release
* Wed Aug  3 2016 ecsos@opensuse.org
- update to 2.16.2
  see https://piwik.org/changelog/piwik-2-16-2/
  - This is a security release
* Tue Apr 12 2016 ecsos@opensuse.org
- update to 2.16.1
  see http://piwik.org/changelog/piwik-2-16-1/
  - This is a security release
- Drop piwik-manifest_unneeded_files.patch: It's now in upstream
* Thu Feb  4 2016 ecsos@opensuse.org
- update to 2.16.0
  see http://piwik.org/changelog/piwik-2-16-0/
* Fri Oct 23 2015 ecsos@opensuse.org
- update to 2.15.0
  see http://piwik.org/changelog/piwik-2-15-0/
- insert attention mark for php caches in README.SUSE
- activate and update manifest patch
* Thu Aug  6 2015 ecsos@opensuse.org
- update to 2.14.3
  - #8439 Install of 2.14.2 blocked by permissions check on
    piwik/config path [by @mnapoli]
  - #8431 Overlay improvements [by @sgiehl, @tsteur]
  - #8352 In Page Overlay sidebar, add icon to let me
    “Open segmented visitor log” [by @sgiehl]
  - #8403 Improve design of Trusted Piwik Hostname setting
    [by @barbushin, @tsteur]
  - #7835 Rename “Widgets & Dashboard” selector or change the
    selector [by @tsteur]
  - #8293 Piwik errors logged in server error log should not have
    HTML [by @mnapoli]
  - #8252 New config entry to set email name in email FROM field
    [by @tsteur]
  - #8472 Fix bug in notification angular directive, do not use
    data-binding for noclear attribute… [by @diosmosis]
  - #8285 UserCountryMap plugin shows wrong options in countries
    select [by @mnapoli]
  - #8432 [automatic translation update] Updated 195 strings in
    32 languages (sk, ar, de, ja, nl, nb, sv, be, bg, ca, cs, da,
    el, es, fa, fi, fr, hi, hu, id, it, ko, pl, pt, ro, ru, sq, sr,
    th, tl, uk, vi) [by @sgiehl]
  - #8474 [automatic translation update] Updated 254 strings in
    37 languages (gl, nb, cs, it, sk, de, el, fr, lt, ar, bg, ca,
    da, es, et, fa, fi, he, hi, hr, id, ja, ko, nl, nn, pl, ro, ru,
    sl, sq, sr, sv, ta, th, tl, tr, vi) [by @sgiehl]
* Wed Jul 29 2015 ecsos@opensuse.org
- update to 2.14.2
  - #8304 Column not found: 1054 Unknown column
    ‘log_visit.location_browser_lang’ in ‘field list'” [by @tsteur]
  - #8365 renderer format is not valid – fatal php error after
    2.14.0
  - #8316 URL parameter for core:archive console command is ignored
    [by @diosmosis, @mattab]
  - #8307 Limit notifications of not authenticated sessions
    [by @tsteur]
  - #8370 Can’t update GrabGravatar plugin [by @tsteur]
  - #8346 node.className.split is not a function on tracking click
    on/near SVG element [by @dandv, @tsteur]
  - #8294 CLI plugin generator doesn’t intercept plugin description
    [by @tsteur]
  - #8257 Site Search report does not display tooltips with metrics
    documentation
  - #7768 Browser info tooltip doesn’t hide
  - #8411 Add System check that checks that shell_exec function is
    enabled [by @mattab]
  - #8407 The string General_Cancel was not loaded in javascript
    [by @tsteur]
  - #8400 Fix emails validation with unknown TLD
    [by @barbushin, @mnapoli]
  - #8379 Travis system extraction part 1 [by @diosmosis]
  - #8374 Tweaks to .travis.yml generator [by @diosmosis]
  - #8376 [automatic translation update] Updated 661 strings in
    8 languages (nl, sv, de, es, ja, lt, pl, nb) [by @sgiehl]
* Sat Jun 13 2015 ecsos@opensuse.org
- initial version 2.13.1
